@@ -108,7 +108,7 @@ public class TestSecurableObjects {
                     MetadataObject.Type.METALAKE,
                     Lists.newArrayList("metalake", "catalog"),
                     Lists.newArrayList(Privileges.UseCatalog.allow())));
-    Assertions.assertTrue(e.getMessage().contains("length of names is 2"));
+    Assertions.assertTrue(e.getMessage().contains("the length of names must be 1"));
     e =
         Assertions.assertThrows(
             IllegalArgumentException.class,
@@ -117,7 +117,7 @@ public class TestSecurableObjects {
                     MetadataObject.Type.CATALOG,
                     Lists.newArrayList("metalake", "catalog"),
                     Lists.newArrayList(Privileges.UseCatalog.allow())));
-    Assertions.assertTrue(e.getMessage().contains("length of names is 2"));
+    Assertions.assertTrue(e.getMessage().contains("the length of names must be 1"));
 
     e =
         Assertions.assertThrows(
@@ -127,7 +127,7 @@ public class TestSecurableObjects {
                     MetadataObject.Type.TABLE,
                     Lists.newArrayList("metalake"),
                     Lists.newArrayList(Privileges.SelectTable.allow())));
-    Assertions.assertTrue(e.getMessage().contains("the length of names is 1"));
+    Assertions.assertTrue(e.getMessage().contains("the length of names must be 3"));
     e =
         Assertions.assertThrows(
             IllegalArgumentException.class,
@@ -136,7 +136,7 @@ public class TestSecurableObjects {
                     MetadataObject.Type.TOPIC,
                     Lists.newArrayList("metalake"),
                     Lists.newArrayList(Privileges.ConsumeTopic.allow())));
-    Assertions.assertTrue(e.getMessage().contains("the length of names is 1"));
+    Assertions.assertTrue(e.getMessage().contains("the length of names must be 3"));
     e =
         Assertions.assertThrows(
             IllegalArgumentException.class,
@@ -145,7 +145,7 @@ public class TestSecurableObjects {
                     MetadataObject.Type.FILESET,
                     Lists.newArrayList("metalake"),
                     Lists.newArrayList(Privileges.ReadFileset.allow())));
-    Assertions.assertTrue(e.getMessage().contains("the length of names is 1"));
+    Assertions.assertTrue(e.getMessage().contains("the length of names must be 3"));
 
     e =
         Assertions.assertThrows(
@@ -155,7 +155,7 @@ public class TestSecurableObjects {
                     MetadataObject.Type.SCHEMA,
                     Lists.newArrayList("catalog", "schema", "table"),
                     Lists.newArrayList(Privileges.UseSchema.allow())));
-    Assertions.assertTrue(e.getMessage().contains("the length of names is 3"));
+    Assertions.assertTrue(e.getMessage().contains("the length of names must be 2"));
   }
 
   @Test
@@ -177,9 +177,16 @@ public class TestSecurableObjects {
     Privilege manageUsers = Privileges.ManageUsers.allow();
     Privilege manageGroups = Privileges.ManageGroups.allow();
     Privilege manageGrants = Privileges.ManageGrants.allow();
-    Privilege createModel = Privileges.CreateModel.allow();
-    Privilege createModelVersion = Privileges.CreateModelVersion.allow();
+    Privilege createModel = Privileges.RegisterModel.allow();
+    Privilege createModelVersion = Privileges.LinkModelVersion.allow();
     Privilege useModel = Privileges.UseModel.allow();
+    Privilege createTag = Privileges.CreateTag.allow();
+    Privilege applyTag = Privileges.ApplyTag.allow();
+    Privilege createPolicy = Privileges.CreatePolicy.allow();
+    Privilege applyPolicy = Privileges.ApplyPolicy.allow();
+    Privilege registerJobTemplate = Privileges.RegisterJobTemplate.allow();
+    Privilege runJob = Privileges.RunJob.allow();
+    Privilege useJobTemplate = Privileges.UseJobTemplate.allow();
 
     // Test create catalog
     Assertions.assertTrue(createCatalog.canBindTo(MetadataObject.Type.METALAKE));
@@ -382,5 +389,72 @@ public class TestSecurableObjects {
     Assertions.assertFalse(useModel.canBindTo(MetadataObject.Type.ROLE));
     Assertions.assertFalse(useModel.canBindTo(MetadataObject.Type.COLUMN));
     Assertions.assertTrue(useModel.canBindTo(MetadataObject.Type.MODEL));
+
+    Assertions.assertTrue(createTag.canBindTo(MetadataObject.Type.METALAKE));
+    Assertions.assertFalse(createTag.canBindTo(MetadataObject.Type.CATALOG));
+
+    Assertions.assertTrue(applyTag.canBindTo(MetadataObject.Type.METALAKE));
+    Assertions.assertTrue(applyTag.canBindTo(MetadataObject.Type.TAG));
+    Assertions.assertFalse(applyTag.canBindTo(MetadataObject.Type.CATALOG));
+    Assertions.assertFalse(applyTag.canBindTo(MetadataObject.Type.SCHEMA));
+    Assertions.assertFalse(applyTag.canBindTo(MetadataObject.Type.TABLE));
+    Assertions.assertFalse(applyTag.canBindTo(MetadataObject.Type.MODEL));
+
+    Assertions.assertFalse(useModel.canBindTo(MetadataObject.Type.TOPIC));
+    Assertions.assertFalse(useModel.canBindTo(MetadataObject.Type.FILESET));
+    Assertions.assertFalse(useModel.canBindTo(MetadataObject.Type.ROLE));
+
+    Assertions.assertTrue(createPolicy.canBindTo(MetadataObject.Type.METALAKE));
+    Assertions.assertFalse(createPolicy.canBindTo(MetadataObject.Type.POLICY));
+    Assertions.assertFalse(createPolicy.canBindTo(MetadataObject.Type.CATALOG));
+    Assertions.assertFalse(createPolicy.canBindTo(MetadataObject.Type.SCHEMA));
+    Assertions.assertFalse(createPolicy.canBindTo(MetadataObject.Type.TABLE));
+    Assertions.assertFalse(createPolicy.canBindTo(MetadataObject.Type.MODEL));
+    Assertions.assertFalse(createPolicy.canBindTo(MetadataObject.Type.TOPIC));
+    Assertions.assertFalse(createPolicy.canBindTo(MetadataObject.Type.FILESET));
+    Assertions.assertFalse(createPolicy.canBindTo(MetadataObject.Type.ROLE));
+
+    Assertions.assertTrue(applyPolicy.canBindTo(MetadataObject.Type.METALAKE));
+    Assertions.assertTrue(applyPolicy.canBindTo(MetadataObject.Type.POLICY));
+    Assertions.assertFalse(applyTag.canBindTo(MetadataObject.Type.CATALOG));
+    Assertions.assertFalse(applyTag.canBindTo(MetadataObject.Type.SCHEMA));
+    Assertions.assertFalse(applyTag.canBindTo(MetadataObject.Type.TABLE));
+    Assertions.assertFalse(applyTag.canBindTo(MetadataObject.Type.MODEL));
+    Assertions.assertFalse(useModel.canBindTo(MetadataObject.Type.TOPIC));
+    Assertions.assertFalse(useModel.canBindTo(MetadataObject.Type.FILESET));
+    Assertions.assertFalse(useModel.canBindTo(MetadataObject.Type.ROLE));
+
+    Assertions.assertTrue(registerJobTemplate.canBindTo(MetadataObject.Type.METALAKE));
+    Assertions.assertFalse(registerJobTemplate.canBindTo(MetadataObject.Type.CATALOG));
+    Assertions.assertFalse(registerJobTemplate.canBindTo(MetadataObject.Type.SCHEMA));
+    Assertions.assertFalse(registerJobTemplate.canBindTo(MetadataObject.Type.TABLE));
+    Assertions.assertFalse(registerJobTemplate.canBindTo(MetadataObject.Type.TOPIC));
+    Assertions.assertFalse(registerJobTemplate.canBindTo(MetadataObject.Type.FILESET));
+    Assertions.assertFalse(registerJobTemplate.canBindTo(MetadataObject.Type.ROLE));
+    Assertions.assertFalse(registerJobTemplate.canBindTo(MetadataObject.Type.COLUMN));
+    Assertions.assertFalse(registerJobTemplate.canBindTo(MetadataObject.Type.JOB_TEMPLATE));
+    Assertions.assertFalse(registerJobTemplate.canBindTo(MetadataObject.Type.JOB));
+
+    Assertions.assertTrue(runJob.canBindTo(MetadataObject.Type.METALAKE));
+    Assertions.assertFalse(runJob.canBindTo(MetadataObject.Type.CATALOG));
+    Assertions.assertFalse(runJob.canBindTo(MetadataObject.Type.SCHEMA));
+    Assertions.assertFalse(runJob.canBindTo(MetadataObject.Type.TABLE));
+    Assertions.assertFalse(runJob.canBindTo(MetadataObject.Type.TOPIC));
+    Assertions.assertFalse(runJob.canBindTo(MetadataObject.Type.FILESET));
+    Assertions.assertFalse(runJob.canBindTo(MetadataObject.Type.ROLE));
+    Assertions.assertFalse(runJob.canBindTo(MetadataObject.Type.COLUMN));
+    Assertions.assertFalse(runJob.canBindTo(MetadataObject.Type.JOB));
+    Assertions.assertFalse(runJob.canBindTo(MetadataObject.Type.JOB_TEMPLATE));
+
+    Assertions.assertTrue(useJobTemplate.canBindTo(MetadataObject.Type.METALAKE));
+    Assertions.assertFalse(useJobTemplate.canBindTo(MetadataObject.Type.CATALOG));
+    Assertions.assertFalse(useJobTemplate.canBindTo(MetadataObject.Type.SCHEMA));
+    Assertions.assertFalse(useJobTemplate.canBindTo(MetadataObject.Type.TABLE));
+    Assertions.assertFalse(useJobTemplate.canBindTo(MetadataObject.Type.TOPIC));
+    Assertions.assertFalse(useJobTemplate.canBindTo(MetadataObject.Type.FILESET));
+    Assertions.assertFalse(useJobTemplate.canBindTo(MetadataObject.Type.ROLE));
+    Assertions.assertFalse(useJobTemplate.canBindTo(MetadataObject.Type.COLUMN));
+    Assertions.assertTrue(useJobTemplate.canBindTo(MetadataObject.Type.JOB_TEMPLATE));
+    Assertions.assertFalse(useJobTemplate.canBindTo(MetadataObject.Type.JOB));
   }
 }
