@@ -28,6 +28,9 @@ plugins {
 dependencies {
   implementation(project(":bundles:aws"))
   implementation(libs.hadoop3.aws)
+  implementation(libs.aws.iam)
+  implementation(libs.aws.policy)
+  implementation(libs.aws.sts)
   implementation(libs.hadoop3.client.api)
   implementation(libs.hadoop3.client.runtime)
 }
@@ -39,6 +42,16 @@ tasks.withType(ShadowJar::class.java) {
 
   dependencies {
     exclude(dependency("org.slf4j:slf4j-api"))
+
+    // Exclude Gravitino modules to prevent class duplication and "Split Packages" issues.
+    // These modules (api, common, catalogs) are already provided by the Gravitino server and gravitino-filesystem-hadoop3-runtime.
+    // Including them here would cause the Relocation rules below to incorrectly modify
+    // method signatures (e.g., JsonUtils.anyFieldMapper returning a shaded ObjectMapper),
+    // leading to java.lang.NoSuchMethodError at runtime.
+    exclude(project(":api"))
+    exclude(project(":common"))
+    exclude(project(":catalogs:catalog-common"))
+    exclude(project(":catalogs:hadoop-common"))
   }
 
   relocate("com.fasterxml.jackson", "org.apache.gravitino.aws.shaded.com.fasterxml.jackson")
@@ -51,7 +64,6 @@ tasks.withType(ShadowJar::class.java) {
   relocate("org.checkerframework", "org.apache.gravitino.aws.shaded.org.checkerframework")
   relocate("org.reactivestreams", "org.apache.gravitino.aws.shaded.org.reactivestreams")
   relocate("org.wildfly.openssl", "org.apache.gravitino.aws.shaded.org.wildfly.openssl")
-  relocate("software.amazon", "org.apache.gravitino.aws.shaded.software.amazon")
 
   mergeServiceFiles()
 }
