@@ -23,8 +23,13 @@ plugins {
 
 // try to avoid adding extra dependencies because it is used by catalogs and connectors.
 dependencies {
+  implementation(project(":common")) {
+    exclude("*")
+  }
+
   implementation(libs.commons.lang3)
   implementation(libs.guava)
+  implementation(libs.jakarta.validation.api)
   implementation(libs.slf4j.api)
 
   testImplementation(libs.junit.jupiter.api)
