@@ -57,6 +57,7 @@ public class IcebergConstants {
 
   public static final String COMMENT = "comment";
   public static final String CREATOR = "creator";
+  public static final String OWNER = "owner";
   public static final String LOCATION = "location";
   public static final String CURRENT_SNAPSHOT_ID = "current-snapshot-id";
   public static final String CHERRY_PICK_SNAPSHOT_ID = "cherry-pick-snapshot-id";
@@ -93,4 +94,9 @@ public class IcebergConstants {
   public static final String ICEBERG_REST_DEFAULT_METALAKE = "gravitino";
   public static final String ICEBERG_REST_DEFAULT_CATALOG = "default_catalog";
   public static final String ICEBERG_REST_DEFAULT_DYNAMIC_CATALOG_NAME = "default-catalog-name";
+
+  public static final String TABLE_METADATA_CACHE_IMPL = "table-metadata-cache-impl";
+  public static final String TABLE_METADATA_CACHE_CAPACITY = "table-metadata-cache-capacity";
+  public static final String TABLE_METADATA_CACHE_EXPIRE_MINUTES =
+      "table-metadata-cache-expire-minutes";
 }
