@@ -40,13 +40,15 @@ dependencies {
   implementation(project(":core")) {
     exclude(group = "*")
   }
+  implementation(libs.awaitility)
   implementation(libs.caffeine)
   implementation(libs.commons.lang3)
   implementation(libs.commons.io)
   implementation(libs.hadoop3.client.api)
   implementation(libs.hadoop3.client.runtime)
   implementation(libs.slf4j.api)
-  implementation(libs.awaitility)
+  implementation(libs.metrics.caffeine)
+  implementation(libs.metrics.core)
 
   compileOnly(libs.guava)
 
@@ -75,7 +77,7 @@ dependencies {
 }
 
 tasks {
-  val runtimeJars by registering(Copy::class) {
+  register("runtimeJars", Copy::class) {
     from(configurations.runtimeClasspath)
     into("build/libs")
   }
