@@ -950,4 +950,22 @@ public class TestTableFormat {
 
     Assertions.assertEquals(expected.trim(), outputString.trim());
   }
+
+  @Test
+  void testUserDetailsWithNullRoles() {
+    CommandContext mockContext = TestCliUtil.getMockContext();
+    User mockUser = mock(User.class);
+    when(mockUser.name()).thenReturn("user1");
+    when(mockUser.roles()).thenReturn(null);
+
+    TableFormat.output(mockUser, mockContext);
+    String output = new String(outContent.toByteArray(), StandardCharsets.UTF_8).trim();
+    Assertions.assertEquals(
+        "+-------+-------+\n"
+            + "| Name  | Roles |\n"
+            + "+-------+-------+\n"
+            + "| user1 |       |\n"
+            + "+-------+-------+",
+        output);
+  }
 }
