@@ -1596,7 +1596,7 @@ public class GravitinoMetalake extends MetalakeDTO
 
     @Override
     public GravitinoMetalake build() {
-      Preconditions.checkNotNull(restClient, "restClient must be set");
+      Preconditions.checkArgument(restClient != null, "restClient must be set");
       Preconditions.checkArgument(StringUtils.isNotBlank(name), "name must not be null or empty");
       Preconditions.checkArgument(audit != null, "audit must not be null");
 
@@ -1618,7 +1618,9 @@ public class GravitinoMetalake extends MetalakeDTO
     return super.equals(that);
   }
 
-  /** @return the builder for creating a new instance of GravitinoMetaLake. */
+  /**
+   * @return the builder for creating a new instance of GravitinoMetaLake.
+   */
   public static Builder builder() {
     return new Builder();
   }
