@@ -32,7 +32,6 @@ from gravitino.exceptions.base import (
 )
 from gravitino.filesystem.gvfs_base_operations import (
     BaseGVFSOperations,
-    FilesetPathNotFoundError,
 )
 from gravitino.filesystem.gvfs_config import GVFSConfig
 from gravitino.filesystem.gvfs_default_operations import DefaultGVFSOperations
@@ -76,6 +75,7 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         self._operations = self._get_gvfs_operations_class(
             server_uri, metalake_name, options
         )
+        self._hook.set_operations_context(self._operations)
 
         super().__init__(**kwargs)
 
@@ -94,7 +94,7 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
     @staticmethod
     def _with_exception_translation(operation: FilesetDataOperation):
         """
-        Decorator to translate fileset metadata not found exceptions into FilesetPathNotFoundError.
+        Decorator to translate fileset metadata not found exceptions into FileNotFoundError.
         :param operation: The operation being performed.
         """
 
@@ -106,15 +106,15 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
                 except (NoSuchCatalogException, CatalogNotInUseException) as e:
                     message = f"Cannot get fileset catalog during {operation}"
                     logger.warning("%s, %s", message, str(e))
-                    raise FilesetPathNotFoundError(message) from e
+                    raise FileNotFoundError(message) from e
                 except NoSuchFilesetException as e:
                     message = f"Cannot get fileset during {operation}"
                     logger.warning("%s, %s", message, str(e))
-                    raise FilesetPathNotFoundError(message) from e
+                    raise FileNotFoundError(message) from e
                 except NoSuchLocationNameException as e:
                     message = f"Cannot find location name during {operation}"
                     logger.warning("%s, %s", message, str(e))
-                    raise FilesetPathNotFoundError(message) from e
+                    raise FileNotFoundError(message) from e
 
             return wrapper
 
@@ -133,12 +133,16 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         :param kwargs: Extra args
         :return If details is true, returns a list of file info dicts, else returns a list of file paths
         """
-        new_path = self._hook.pre_ls(path, detail, **kwargs)
-        decorated_ls = self._with_exception_translation(
-            FilesetDataOperation.LIST_STATUS
-        )(self._operations.ls)
-        result = decorated_ls(new_path, detail, **kwargs)
-        return self._hook.post_ls(detail, result, **kwargs)
+        try:
+            new_path = self._hook.pre_ls(path, detail, **kwargs)
+            decorated_ls = self._with_exception_translation(
+                FilesetDataOperation.LIST_STATUS
+            )(self._operations.ls)
+            result = decorated_ls(new_path, detail, **kwargs)
+            return self._hook.post_ls(detail, result, **kwargs)
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            # Hook will either provide fallback value or re-raise the exception
+            return self._hook.on_ls_failure(path, e, **kwargs)
 
     def info(self, path, **kwargs):
         """Get file info.
@@ -146,15 +150,19 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         :param kwargs: Extra args
         :return A file info dict
         """
-        new_path = self._hook.pre_info(path, **kwargs)
-        decorated_info = self._with_exception_translation(
-            FilesetDataOperation.GET_FILE_STATUS
-        )(self._operations.info)
-        result = decorated_info(new_path, **kwargs)
-        return self._hook.post_info(
-            result,
-            **kwargs,
-        )
+        try:
+            new_path = self._hook.pre_info(path, **kwargs)
+            decorated_info = self._with_exception_translation(
+                FilesetDataOperation.GET_FILE_STATUS
+            )(self._operations.info)
+            result = decorated_info(new_path, **kwargs)
+            return self._hook.post_info(
+                result,
+                **kwargs,
+            )
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            # Hook will either provide fallback value or re-raise the exception
+            return self._hook.on_info_failure(path, e, **kwargs)
 
     def exists(self, path, **kwargs):
         """Check if a file or a directory exists.
@@ -162,20 +170,24 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         :param kwargs: Extra args
         :return If a file or directory exists, it returns True, otherwise False
         """
-        new_path = self._hook.pre_exists(path, **kwargs)
-        decorated_exists = self._with_exception_translation(
-            FilesetDataOperation.EXISTS
-        )(self._operations.exists)
         try:
-            result = decorated_exists(new_path, **kwargs)
-        except FilesetPathNotFoundError:
-            return False
+            new_path = self._hook.pre_exists(path, **kwargs)
+            decorated_exists = self._with_exception_translation(
+                FilesetDataOperation.EXISTS
+            )(self._operations.exists)
+            try:
+                result = decorated_exists(new_path, **kwargs)
+            except FileNotFoundError:
+                return False
 
-        return self._hook.post_exists(
-            new_path,
-            result,
-            **kwargs,
-        )
+            return self._hook.post_exists(
+                new_path,
+                result,
+                **kwargs,
+            )
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            # Hook will either provide fallback value or re-raise the exception
+            return self._hook.on_exists_failure(path, e, **kwargs)
 
     def cp_file(self, path1, path2, **kwargs):
         """Copy a file.
@@ -183,12 +195,15 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         :param path2: Virtual dst fileset path, should be consistent with the src path fileset identifier
         :param kwargs: Extra args
         """
-        new_path1, new_path2 = self._hook.pre_cp_file(path1, path2, **kwargs)
-        decorated_cp_file = self._with_exception_translation(
-            FilesetDataOperation.COPY_FILE
-        )(self._operations.cp_file)
-        decorated_cp_file(new_path1, new_path2, **kwargs)
-        self._hook.post_cp_file(new_path1, new_path2, **kwargs)
+        try:
+            new_path1, new_path2 = self._hook.pre_cp_file(path1, path2, **kwargs)
+            decorated_cp_file = self._with_exception_translation(
+                FilesetDataOperation.COPY_FILE
+            )(self._operations.cp_file)
+            decorated_cp_file(new_path1, new_path2, **kwargs)
+            self._hook.post_cp_file(new_path1, new_path2, **kwargs)
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            self._hook.on_cp_file_failure(path1, path2, e, **kwargs)
 
     def mv(self, path1, path2, recursive=False, maxdepth=None, **kwargs):
         """Move a file to another directory.
@@ -200,14 +215,17 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         :param maxdepth: Maximum depth of recursive move
         :param kwargs: Extra args
         """
-        new_path1, new_path2 = self._hook.pre_mv(
-            path1, path2, recursive, maxdepth, **kwargs
-        )
-        decorated_mv = self._with_exception_translation(FilesetDataOperation.RENAME)(
-            self._operations.mv
-        )
-        decorated_mv(new_path1, new_path2, recursive, maxdepth, **kwargs)
-        self._hook.post_mv(new_path1, new_path2, recursive, maxdepth, **kwargs)
+        try:
+            new_path1, new_path2 = self._hook.pre_mv(
+                path1, path2, recursive, maxdepth, **kwargs
+            )
+            decorated_mv = self._with_exception_translation(
+                FilesetDataOperation.RENAME
+            )(self._operations.mv)
+            decorated_mv(new_path1, new_path2, recursive, maxdepth, **kwargs)
+            self._hook.post_mv(new_path1, new_path2, recursive, maxdepth, **kwargs)
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            self._hook.on_mv_failure(path1, path2, recursive, maxdepth, e, **kwargs)
 
     def _rm(self, path):
         raise GravitinoRuntimeException(
@@ -221,23 +239,29 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
                 When removing a directory, this parameter should be True.
         :param maxdepth: The maximum depth to remove the directory recursively.
         """
-        new_path = self._hook.pre_rm(path, recursive, maxdepth)
-        decorated_rm = self._with_exception_translation(FilesetDataOperation.DELETE)(
-            self._operations.rm
-        )
-        decorated_rm(new_path, recursive, maxdepth)
-        self._hook.post_rm(new_path, recursive, maxdepth)
+        try:
+            new_path = self._hook.pre_rm(path, recursive, maxdepth)
+            decorated_rm = self._with_exception_translation(
+                FilesetDataOperation.DELETE
+            )(self._operations.rm)
+            decorated_rm(new_path, recursive, maxdepth)
+            self._hook.post_rm(new_path, recursive, maxdepth)
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            self._hook.on_rm_failure(path, recursive, maxdepth, e)
 
     def rm_file(self, path):
         """Remove a file.
         :param path: Virtual fileset path
         """
-        new_path = self._hook.pre_rm_file(path)
-        decorated_rm_file = self._with_exception_translation(
-            FilesetDataOperation.DELETE
-        )(self._operations.rm_file)
-        decorated_rm_file(new_path)
-        self._hook.post_rm_file(new_path)
+        try:
+            new_path = self._hook.pre_rm_file(path)
+            decorated_rm_file = self._with_exception_translation(
+                FilesetDataOperation.DELETE
+            )(self._operations.rm_file)
+            decorated_rm_file(new_path)
+            self._hook.post_rm_file(new_path)
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            self._hook.on_rm_file_failure(path, e)
 
     def rmdir(self, path):
         """Remove a directory.
@@ -245,12 +269,15 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         And it will throw an exception if delete a directory which is non-empty for LocalFileSystem.
         :param path: Virtual fileset path
         """
-        new_path = self._hook.pre_rmdir(path)
-        decorated_rmdir = self._with_exception_translation(FilesetDataOperation.DELETE)(
-            self._operations.rmdir
-        )
-        decorated_rmdir(new_path)
-        self._hook.post_rmdir(new_path)
+        try:
+            new_path = self._hook.pre_rmdir(path)
+            decorated_rmdir = self._with_exception_translation(
+                FilesetDataOperation.DELETE
+            )(self._operations.rmdir)
+            decorated_rmdir(new_path)
+            self._hook.post_rmdir(new_path)
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            self._hook.on_rmdir_failure(path, e)
 
     def open(
         self,
@@ -270,45 +297,51 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         :param kwargs: Extra args
         :return A file-like object from the filesystem
         """
-        new_path = self._hook.pre_open(
-            path, mode, block_size, cache_options, compression, **kwargs
-        )
-        if mode in ("w", "wb"):
-            data_operation = FilesetDataOperation.OPEN_AND_WRITE
-        elif mode in ("a", "ab"):
-            data_operation = FilesetDataOperation.OPEN_AND_APPEND
-        else:
-            data_operation = FilesetDataOperation.OPEN
-
-        decorated_open = self._with_exception_translation(data_operation)(
-            self._operations.open
-        )
         try:
-            result = decorated_open(
+            new_path = self._hook.pre_open(
+                path, mode, block_size, cache_options, compression, **kwargs
+            )
+            if mode in ("w", "wb"):
+                data_operation = FilesetDataOperation.OPEN_AND_WRITE
+            elif mode in ("a", "ab"):
+                data_operation = FilesetDataOperation.OPEN_AND_APPEND
+            else:
+                data_operation = FilesetDataOperation.OPEN
+
+            decorated_open = self._with_exception_translation(data_operation)(
+                self._operations.open
+            )
+            try:
+                result = decorated_open(
+                    new_path,
+                    mode,
+                    block_size,
+                    cache_options,
+                    compression,
+                    **kwargs,
+                )
+            except FileNotFoundError as e:
+                if mode in ("w", "wb", "x", "xb", "a", "ab"):
+                    raise OSError(
+                        f"Fileset is not found for path: {new_path} for operation OPEN. This "
+                        f"may be caused by fileset related metadata not found or not in use "
+                        f"in Gravitino,"
+                    ) from e
+                raise
+            return self._hook.post_open(
                 new_path,
                 mode,
                 block_size,
                 cache_options,
                 compression,
+                result,
                 **kwargs,
             )
-        except FilesetPathNotFoundError as e:
-            if mode in ("w", "wb", "x", "xb", "a", "ab"):
-                raise OSError(
-                    f"Fileset is not found for path: {new_path} for operation OPEN. This "
-                    f"may be caused by fileset related metadata not found or not in use "
-                    f"in Gravitino,"
-                ) from e
-            raise
-        return self._hook.post_open(
-            new_path,
-            mode,
-            block_size,
-            cache_options,
-            compression,
-            result,
-            **kwargs,
-        )
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            # Hook will either provide fallback value or re-raise the exception
+            return self._hook.on_open_failure(
+                path, mode, block_size, cache_options, compression, e, **kwargs
+            )
 
     def mkdir(self, path, create_parents=True, **kwargs):
         """Make a directory.
@@ -318,38 +351,48 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         :param create_parents: Create parent directories if missing when set to True
         :param kwargs: Extra args
         """
-        new_path = self._hook.pre_mkdir(path, create_parents, **kwargs)
-        decorated_mkdir = self._with_exception_translation(FilesetDataOperation.MKDIRS)(
-            self._operations.mkdir
-        )
         try:
-            decorated_mkdir(new_path, create_parents, **kwargs)
-        except FilesetPathNotFoundError as e:
-            raise OSError(
-                f"Fileset is not found for path: {new_path} for operation MKDIRS. This "
-                f"may be caused by fileset related metadata not found or not in use "
-                f"in Gravitino,"
-            ) from e
-        self._hook.post_mkdir(new_path, create_parents, **kwargs)
+            new_path = self._hook.pre_mkdir(path, create_parents, **kwargs)
+            try:
+                self._operations.mkdir(new_path, create_parents, **kwargs)
+            except (
+                NoSuchCatalogException,
+                CatalogNotInUseException,
+                NoSuchFilesetException,
+                NoSuchLocationNameException,
+            ) as e:
+                raise OSError(
+                    f"Fileset is not found for path: {new_path} for operation MKDIRS. This "
+                    f"may be caused by fileset related metadata not found or not in use "
+                    f"in Gravitino,"
+                ) from e
+            self._hook.post_mkdir(new_path, create_parents, **kwargs)
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            self._hook.on_mkdir_failure(path, create_parents, e, **kwargs)
 
     def makedirs(self, path, exist_ok=True):
         """Make a directory recursively.
         :param path: Virtual fileset path
         :param exist_ok: Continue if a directory already exists
         """
-        new_path = self._hook.pre_makedirs(path, exist_ok)
-        decorated_makedirs = self._with_exception_translation(
-            FilesetDataOperation.MKDIRS
-        )(self._operations.makedirs)
         try:
-            decorated_makedirs(new_path, exist_ok)
-        except FilesetPathNotFoundError as e:
-            raise OSError(
-                f"Fileset is not found for path: {new_path} for operation MKDIRS. This "
-                f"may be caused by fileset related metadata not found or not in use "
-                f"in Gravitino,"
-            ) from e
-        self._hook.post_makedirs(new_path, exist_ok)
+            new_path = self._hook.pre_makedirs(path, exist_ok)
+            try:
+                self._operations.makedirs(new_path, exist_ok)
+            except (
+                NoSuchCatalogException,
+                CatalogNotInUseException,
+                NoSuchFilesetException,
+                NoSuchLocationNameException,
+            ) as e:
+                raise OSError(
+                    f"Fileset is not found for path: {new_path} for operation MKDIRS. This "
+                    f"may be caused by fileset related metadata not found or not in use "
+                    f"in Gravitino,"
+                ) from e
+            self._hook.post_makedirs(new_path, exist_ok)
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            self._hook.on_makedirs_failure(path, exist_ok, e)
 
     def created(self, path):
         """Return the created timestamp of a file as a datetime.datetime
@@ -357,30 +400,38 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         :param path: Virtual fileset path
         :return Created time(datetime.datetime)
         """
-        new_path = self._hook.pre_created(path)
-        decorated_created = self._with_exception_translation(
-            FilesetDataOperation.CREATED_TIME
-        )(self._operations.created)
-        result = decorated_created(new_path)
-        return self._hook.post_created(
-            new_path,
-            result,
-        )
+        try:
+            new_path = self._hook.pre_created(path)
+            decorated_created = self._with_exception_translation(
+                FilesetDataOperation.CREATED_TIME
+            )(self._operations.created)
+            result = decorated_created(new_path)
+            return self._hook.post_created(
+                new_path,
+                result,
+            )
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            # Hook will either provide fallback value or re-raise the exception
+            return self._hook.on_created_failure(path, e)
 
     def modified(self, path):
         """Returns the modified time of the path file if it exists.
         :param path: Virtual fileset path
         :return Modified time(datetime.datetime)
         """
-        new_path = self._hook.pre_modified(path)
-        decorated_modified = self._with_exception_translation(
-            FilesetDataOperation.MODIFIED_TIME
-        )(self._operations.modified)
-        result = decorated_modified(new_path)
-        return self._hook.post_modified(
-            new_path,
-            result,
-        )
+        try:
+            new_path = self._hook.pre_modified(path)
+            decorated_modified = self._with_exception_translation(
+                FilesetDataOperation.MODIFIED_TIME
+            )(self._operations.modified)
+            result = decorated_modified(new_path)
+            return self._hook.post_modified(
+                new_path,
+                result,
+            )
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            # Hook will either provide fallback value or re-raise the exception
+            return self._hook.on_modified_failure(path, e)
 
     def cat_file(self, path, start=None, end=None, **kwargs):
         """Get the content of a file.
@@ -390,18 +441,22 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         :param kwargs: Extra args
         :return File content
         """
-        new_path = self._hook.pre_cat_file(path, start, end, **kwargs)
-        decorated_cat_file = self._with_exception_translation(
-            FilesetDataOperation.CAT_FILE
-        )(self._operations.cat_file)
-        result = decorated_cat_file(new_path, start, end, **kwargs)
-        return self._hook.post_cat_file(
-            new_path,
-            start,
-            end,
-            result,
-            **kwargs,
-        )
+        try:
+            new_path = self._hook.pre_cat_file(path, start, end, **kwargs)
+            decorated_cat_file = self._with_exception_translation(
+                FilesetDataOperation.CAT_FILE
+            )(self._operations.cat_file)
+            result = decorated_cat_file(new_path, start, end, **kwargs)
+            return self._hook.post_cat_file(
+                new_path,
+                start,
+                end,
+                result,
+                **kwargs,
+            )
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            # Hook will either provide fallback value or re-raise the exception
+            return self._hook.on_cat_file_failure(path, start, end, e, **kwargs)
 
     def get_file(self, rpath, lpath, callback=None, outfile=None, **kwargs):
         """Copy single remote file to local.
@@ -411,18 +466,23 @@ class GravitinoVirtualFileSystem(fsspec.AbstractFileSystem):
         :param outfile: The output file path
         :param kwargs: Extra args
         """
-        new_rpath = self._hook.pre_get_file(rpath, lpath, callback, outfile, **kwargs)
-        decorated_get_file = self._with_exception_translation(
-            FilesetDataOperation.GET_FILE_STATUS
-        )(self._operations.get_file)
-        decorated_get_file(
-            new_rpath,
-            lpath,
-            callback,
-            outfile,
-            **kwargs,
-        )
-        self._hook.post_get_file(new_rpath, lpath, outfile, **kwargs)
+        try:
+            new_rpath = self._hook.pre_get_file(
+                rpath, lpath, callback, outfile, **kwargs
+            )
+            decorated_get_file = self._with_exception_translation(
+                FilesetDataOperation.GET_FILE_STATUS
+            )(self._operations.get_file)
+            decorated_get_file(
+                new_rpath,
+                lpath,
+                callback,
+                outfile,
+                **kwargs,
+            )
+            self._hook.post_get_file(new_rpath, lpath, outfile, **kwargs)
+        except Exception as e:  # pylint: disable=broad-exception-caught
+            self._hook.on_get_file_failure(rpath, lpath, callback, outfile, e, **kwargs)
 
     def _get_hook_class(
         self, options: Optional[Dict[str, str]]
