@@ -52,6 +52,7 @@ class TestGvfsWithGCS(TestGvfsWithHDFS):
     key_file = os.environ.get("GCS_SERVICE_ACCOUNT_JSON_PATH")
     bucket_name = os.environ.get("GCS_BUCKET_NAME")
     metalake_name: str = "TestGvfsWithGCS_metalake" + str(randint(1, 10000))
+    catalog_name: str = "test_gvfs_catalog" + str(randint(1, 10000))
 
     def setUp(self):
         self.options = {
@@ -283,8 +284,7 @@ class TestGvfsWithGCS(TestGvfsWithHDFS):
         mkdir_dir = mkdir_dir.replace(self.bucket_name, new_bucket)
         mkdir_actual_dir = mkdir_actual_dir.replace(self.bucket_name, new_bucket)
 
-        with self.assertRaises(OSError):
-            fs.mkdir(mkdir_dir, create_parents=True)
+        fs.mkdir(mkdir_dir, create_parents=True)
         self.assertFalse(self.fs.exists(mkdir_actual_dir))
 
     def test_makedirs(self):
