@@ -20,7 +20,7 @@ import unittest
 from enum import Enum
 from unittest.mock import patch
 
-from gravitino.api.types.types import Types
+from gravitino.api.rel.types.types import Types
 from gravitino.dto.rel.expressions.field_reference_dto import FieldReferenceDTO
 from gravitino.dto.rel.expressions.literal_dto import LiteralDTO
 from gravitino.dto.rel.partitioning.day_partitioning_dto import DayPartitioningDTO
