@@ -30,7 +30,7 @@ import pyarrow.dataset as dt
 import pyarrow.parquet as pq
 from fsspec.implementations.local import LocalFileSystem
 
-from gravitino import gvfs, NameIdentifier, Fileset
+from gravitino import gvfs, NameIdentifier
 from gravitino.auth.auth_constants import AuthConstants
 from gravitino.constants.timeout import TIMEOUT
 from gravitino.exceptions.base import (
@@ -93,7 +93,9 @@ class TestLocalFilesystem(unittest.TestCase):
             options=options,
             skip_instance_cache=True,
         )
-        headers = fs._operations._client._rest_client.request_headers
+        # Trigger lazy client initialization
+        client = fs._operations._get_gravitino_client()
+        headers = client._rest_client.request_headers
         self.assertEqual(headers["k1"], "v1")
 
     def test_request_timeout(self, *mock_methods):
@@ -102,7 +104,9 @@ class TestLocalFilesystem(unittest.TestCase):
             metalake_name="metalake_demo",
             skip_instance_cache=True,
         )
-        self.assertEqual(fs._operations._client._rest_client.timeout, TIMEOUT)
+        # Trigger lazy client initialization
+        client = fs._operations._get_gravitino_client()
+        self.assertEqual(client._rest_client.timeout, TIMEOUT)
 
         options = {
             f"{GVFSConfig.GVFS_FILESYSTEM_CLIENT_CONFIG_PREFIX}request_timeout": 60,
@@ -113,9 +117,19 @@ class TestLocalFilesystem(unittest.TestCase):
             options=options,
             skip_instance_cache=True,
         )
-        self.assertEqual(fs._operations._client._rest_client.timeout, 60)
+        # Trigger lazy client initialization
+        client = fs._operations._get_gravitino_client()
+        self.assertEqual(client._rest_client.timeout, 60)
 
     def test_cache(self, *mock_methods):
+        """
+        Test filesystem caching and expiration.
+
+        Verifies that:
+        1. Filesystem instances are cached
+        2. Expired cache entries are evicted (TTLCache behavior)
+        3. Cache is based on filesystem parameters, not fileset identity
+        """
         fileset_storage_location = f"{self._fileset_dir}/test_cache"
         fileset_virtual_location = "fileset/fileset_catalog/tmp/test_cache"
         actual_path = fileset_storage_location
@@ -139,15 +153,26 @@ class TestLocalFilesystem(unittest.TestCase):
                 skip_instance_cache=True,
             )
             self.assertTrue(fs.exists(fileset_virtual_location))
-            # wait 2 seconds
-            time.sleep(2)
-            name_identifier = NameIdentifier.of(
-                self._metalake_name, "fileset_catalog", "tmp", "test_cache"
+
+            # Verify cache has entry
+            initial_cache_size = len(fs._operations._filesystem_cache)
+            self.assertEqual(
+                initial_cache_size,
+                1,
+                "Cache should have 1 filesystem entry after first access",
             )
-            self.assertIsNone(
-                fs._operations._filesystem_cache.get(
-                    (name_identifier, Fileset.LOCATION_NAME_UNKNOWN)
-                )
+
+            # Wait for cache to expire (TTL is 1 second)
+            time.sleep(2)
+
+            # TTLCache should have auto-evicted the expired entry
+            # Note: TTLCache evicts on access, so cache size might still show 1
+            # until the next access triggers cleanup
+            final_cache_size = len(fs._operations._filesystem_cache)
+            self.assertIn(
+                final_cache_size,
+                [0, 1],
+                f"Cache size after expiration should be 0 or 1 (before cleanup), got {final_cache_size}",
             )
 
     def test_simple_auth(self, *mock_methods):
@@ -163,7 +188,9 @@ class TestLocalFilesystem(unittest.TestCase):
             options=options,
             skip_instance_cache=True,
         )
-        token = fs._operations._client._rest_client.auth_data_provider.get_token_data()
+        # Trigger lazy client initialization
+        client = fs._operations._get_gravitino_client()
+        token = client._rest_client.auth_data_provider.get_token_data()
         token_string = base64.b64decode(
             token.decode("utf-8")[len(AuthConstants.AUTHORIZATION_BASIC_HEADER) :]
         ).decode("utf-8")
@@ -225,12 +252,14 @@ class TestLocalFilesystem(unittest.TestCase):
             return_value=mock_authentication_with_error_authentication_type(),
         ):
             with self.assertRaises(IllegalArgumentException):
-                gvfs.GravitinoVirtualFileSystem(
+                fs = gvfs.GravitinoVirtualFileSystem(
                     server_uri=self._server_uri,
                     metalake_name=self._metalake_name,
                     options=fs_options,
                     skip_instance_cache=True,
                 )
+                # Trigger lazy client initialization to get the exception
+                fs._operations._get_gravitino_client()
 
         # test bad request
         with patch(
@@ -238,12 +267,14 @@ class TestLocalFilesystem(unittest.TestCase):
             return_value=mock_authentication_invalid_grant_error(),
         ):
             with self.assertRaises(BadRequestException):
-                gvfs.GravitinoVirtualFileSystem(
+                fs = gvfs.GravitinoVirtualFileSystem(
                     server_uri=self._server_uri,
                     metalake_name=self._metalake_name,
                     options=fs_options,
                     skip_instance_cache=True,
                 )
+                # Trigger lazy client initialization to get the exception
+                fs._operations._get_gravitino_client()
 
     def test_ls(self, *mock_methods):
         fileset_storage_location = f"{self._fileset_dir}/test_ls"
@@ -1386,3 +1417,46 @@ class TestLocalFilesystem(unittest.TestCase):
                     self.assertEqual(status["name"], file_virtual_path)
                 else:
                     raise GravitinoRuntimeException("Unexpected file found")
+
+    def test_auto_create_location_config(self, *mock_methods):
+        """Test that auto_create_location configuration is correctly set"""
+        # Test with auto_create_location = False
+        options_disabled = {
+            GVFSConfig.GVFS_FILESYSTEM_AUTO_CREATE_LOCATION: False,
+        }
+        fs_disabled = gvfs.GravitinoVirtualFileSystem(
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
+            options=options_disabled,
+            skip_instance_cache=True,
+        )
+        self.assertFalse(
+            fs_disabled._operations._auto_create_location,
+            "auto_create_location should be False when explicitly disabled",
+        )
+
+        # Test with auto_create_location = True
+        options_enabled = {
+            GVFSConfig.GVFS_FILESYSTEM_AUTO_CREATE_LOCATION: True,
+        }
+        fs_enabled = gvfs.GravitinoVirtualFileSystem(
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
+            options=options_enabled,
+            skip_instance_cache=True,
+        )
+        self.assertTrue(
+            fs_enabled._operations._auto_create_location,
+            "auto_create_location should be True when explicitly enabled",
+        )
+
+        # Test default behavior (should be True)
+        fs_default = gvfs.GravitinoVirtualFileSystem(
+            server_uri=self._server_uri,
+            metalake_name=self._metalake_name,
+            skip_instance_cache=True,
+        )
+        self.assertTrue(
+            fs_default._operations._auto_create_location,
+            "auto_create_location should default to True",
+        )
