@@ -32,7 +32,8 @@ import static org.apache.hc.core5.http.HttpStatus.SC_OK;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
-import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.mockito.ArgumentMatchers.any;
@@ -40,34 +41,40 @@ import static org.mockito.ArgumentMatchers.anyBoolean;
 import static org.mockito.ArgumentMatchers.anyInt;
 import static org.mockito.ArgumentMatchers.anyLong;
 import static org.mockito.ArgumentMatchers.anyShort;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockserver.model.HttpRequest.request;
 import static org.mockserver.model.HttpResponse.response;
 
 import com.fasterxml.jackson.core.JsonProcessingException;
+import com.github.benmanes.caffeine.cache.Cache;
 import com.google.common.collect.ImmutableMap;
+import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.lang.reflect.Field;
 import java.net.SocketTimeoutException;
 import java.net.URISyntaxException;
 import java.nio.charset.StandardCharsets;
+import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Objects;
 import java.util.concurrent.TimeUnit;
-import org.apache.commons.lang3.tuple.Pair;
 import org.apache.gravitino.NameIdentifier;
 import org.apache.gravitino.Version;
 import org.apache.gravitino.dto.AuditDTO;
+import org.apache.gravitino.dto.CatalogDTO;
+import org.apache.gravitino.dto.SchemaDTO;
 import org.apache.gravitino.dto.credential.CredentialDTO;
 import org.apache.gravitino.dto.file.FilesetDTO;
+import org.apache.gravitino.dto.responses.CatalogResponse;
 import org.apache.gravitino.dto.responses.CredentialResponse;
 import org.apache.gravitino.dto.responses.ErrorResponse;
 import org.apache.gravitino.dto.responses.FileLocationResponse;
 import org.apache.gravitino.dto.responses.FilesetResponse;
+import org.apache.gravitino.dto.responses.SchemaResponse;
 import org.apache.gravitino.dto.responses.VersionResponse;
 import org.apache.gravitino.exceptions.NoSuchCatalogException;
 import org.apache.gravitino.exceptions.NoSuchFilesetException;
@@ -167,8 +174,7 @@ public class TestGvfsBase extends GravitinoMockServerBase {
       Mockito.doThrow(new NoSuchFilesetException("fileset not found"))
           .when(mockOps)
           .open(any(), anyInt());
-      assertThrows(
-          FilesetPathNotFoundException.class, () -> fs.open(new Path("gvfs://fileset/"), 1024));
+      assertThrows(FileNotFoundException.class, () -> fs.open(new Path("gvfs://fileset/"), 1024));
 
       // test create
       Mockito.doThrow(new NoSuchCatalogException("fileset catalog not found"))
@@ -184,15 +190,14 @@ public class TestGvfsBase extends GravitinoMockServerBase {
       Mockito.doThrow(new NoSuchLocationNameException("location name not found"))
           .when(mockOps)
           .append(any(), anyInt(), any());
-      assertThrows(
-          FilesetPathNotFoundException.class, () -> fs.append(new Path("gvfs://fileset/"), 1024));
+      assertThrows(FileNotFoundException.class, () -> fs.append(new Path("gvfs://fileset/"), 1024));
 
       // test rename
       Mockito.doThrow(new NoSuchFilesetException("fileset not found"))
           .when(mockOps)
           .rename(any(), any());
       assertThrows(
-          FilesetPathNotFoundException.class,
+          FileNotFoundException.class,
           () -> fs.rename(new Path("gvfs://fileset/"), new Path("gvfs://fileset/new")));
 
       // test delete
@@ -206,21 +211,19 @@ public class TestGvfsBase extends GravitinoMockServerBase {
           .when(mockOps)
           .getFileStatus(any());
       assertThrows(
-          FilesetPathNotFoundException.class, () -> fs.getFileStatus(new Path("gvfs://fileset/")));
+          FileNotFoundException.class, () -> fs.getFileStatus(new Path("gvfs://fileset/")));
 
       // test listStatus
       Mockito.doThrow(new NoSuchFilesetException("fileset not found"))
           .when(mockOps)
           .listStatus(any());
-      assertThrows(
-          FilesetPathNotFoundException.class, () -> fs.listStatus(new Path("gvfs://fileset/")));
+      assertThrows(FileNotFoundException.class, () -> fs.listStatus(new Path("gvfs://fileset/")));
 
       // test listStatus
       Mockito.doThrow(new NoSuchFilesetException("fileset not found"))
           .when(mockOps)
           .listStatus(any());
-      assertThrows(
-          FilesetPathNotFoundException.class, () -> fs.listStatus(new Path("gvfs://fileset/")));
+      assertThrows(FileNotFoundException.class, () -> fs.listStatus(new Path("gvfs://fileset/")));
 
       // test mkdirs
       Mockito.doThrow(new NoSuchFilesetException("fileset not found"))
@@ -288,6 +291,11 @@ public class TestGvfsBase extends GravitinoMockServerBase {
                 .withBody(getJsonString(new VersionResponse(Version.getCurrentVersionDTO()))));
 
     try (FileSystem fs = new Path("gvfs://fileset/").getFileSystem(configuration)) {
+      // Trigger lazy initialization by accessing a path (throws RESTException for mock server 404)
+      assertThrows(
+          RESTException.class,
+          () -> fs.exists(new Path("gvfs://fileset/catalog/schema/fileset/file.txt")));
+      // Verify the request was made with correct headers during client initialization
       mockServer().verify(req, VerificationTimes.once());
     }
   }
@@ -336,15 +344,19 @@ public class TestGvfsBase extends GravitinoMockServerBase {
       buildMockResourceForCredential(filesetName, localPath.toString());
 
       FileSystemTestUtils.mkdirs(managedFilesetPath, gravitinoFileSystem);
-      FileSystem proxyLocalFs =
-          Objects.requireNonNull(
-              ((GravitinoVirtualFileSystem) gravitinoFileSystem)
-                  .getOperations()
-                  .internalFileSystemCache()
-                  .getIfPresent(
-                      Pair.of(
-                          NameIdentifier.of(metalakeName, catalogName, schemaName, "testFSCache"),
-                          null)));
+
+      // Verify the internal cache contains a FileSystem for the local scheme
+      Cache<BaseGVFSOperations.FileSystemCacheKey, FileSystem> cache =
+          ((GravitinoVirtualFileSystem) gravitinoFileSystem)
+              .getOperations()
+              .internalFileSystemCache();
+
+      // The cache should have one entry for the local filesystem
+      assertEquals(1, cache.asMap().size());
+
+      // Get the cached filesystem (should be a local filesystem)
+      FileSystem proxyLocalFs = cache.asMap().values().iterator().next();
+      assertNotNull(proxyLocalFs);
 
       String anotherFilesetName = "test_new_fs";
       Path diffLocalPath =
@@ -394,11 +406,71 @@ public class TestGvfsBase extends GravitinoMockServerBase {
                           .asMap()
                           .size()));
 
-      assertNull(
+      // Verify the cache is empty after eviction
+      assertTrue(
           ((GravitinoVirtualFileSystem) fs)
               .getOperations()
               .internalFileSystemCache()
-              .getIfPresent(Pair.of(NameIdentifier.of("file"), LOCATION_NAME_UNKNOWN)));
+              .asMap()
+              .isEmpty());
+    }
+  }
+
+  @Test
+  public void testCacheReuseAcrossMultipleFilesets() throws IOException {
+    // Create two different filesets that point to the same local directory
+    String fileset1Name = "fileset_cache_reuse_1";
+    String fileset2Name = "fileset_cache_reuse_2";
+
+    // Both filesets point to the same underlying local path
+    Path localPath =
+        FileSystemTestUtils.createLocalDirPrefix(catalogName, schemaName, "shared_cache");
+
+    Path filesetPath1 =
+        FileSystemTestUtils.createFilesetPath(catalogName, schemaName, fileset1Name, true);
+    Path filesetPath2 =
+        FileSystemTestUtils.createFilesetPath(catalogName, schemaName, fileset2Name, true);
+
+    String locationPath1 =
+        String.format(
+            "/api/metalakes/%s/catalogs/%s/schemas/%s/filesets/%s/location",
+            metalakeName, catalogName, schemaName, fileset1Name);
+    String locationPath2 =
+        String.format(
+            "/api/metalakes/%s/catalogs/%s/schemas/%s/filesets/%s/location",
+            metalakeName, catalogName, schemaName, fileset2Name);
+
+    try (FileSystem fs = filesetPath1.getFileSystem(conf)) {
+      // Mock server responses for both filesets pointing to the same location
+      FileLocationResponse fileLocationResponse = new FileLocationResponse(localPath.toString());
+      Map<String, String> queryParams = new HashMap<>();
+      queryParams.put("sub_path", "");
+
+      buildMockResource(Method.GET, locationPath1, queryParams, null, fileLocationResponse, SC_OK);
+      buildMockResource(Method.GET, locationPath2, queryParams, null, fileLocationResponse, SC_OK);
+      buildMockResourceForCredential(fileset1Name, localPath.toString());
+      buildMockResourceForCredential(fileset2Name, localPath.toString());
+
+      // Access first fileset
+      FileSystemTestUtils.mkdirs(filesetPath1, fs);
+
+      Cache<BaseGVFSOperations.FileSystemCacheKey, FileSystem> cache =
+          ((GravitinoVirtualFileSystem) fs).getOperations().internalFileSystemCache();
+
+      // Should have one cached filesystem for the local scheme
+      assertEquals(1, cache.asMap().size());
+      FileSystem cachedFs1 = cache.asMap().values().iterator().next();
+      assertNotNull(cachedFs1);
+
+      // Access second fileset pointing to the same location
+      FileSystemTestUtils.mkdirs(filesetPath2, fs);
+
+      // Should still have only one cached filesystem (reused)
+      assertEquals(1, cache.asMap().size());
+      FileSystem cachedFs2 = cache.asMap().values().iterator().next();
+
+      // Both should be the same instance since they share scheme/authority/user
+      assertSame(cachedFs1, cachedFs2, "FileSystem instances should be reused for same storage");
     }
   }
 
@@ -973,17 +1045,17 @@ public class TestGvfsBase extends GravitinoMockServerBase {
 
       Path testPath = new Path(managedFilesetPath + "/test.txt");
       assertThrows(RuntimeException.class, () -> fs.setWorkingDirectory(testPath));
-      assertThrows(FilesetPathNotFoundException.class, () -> fs.open(testPath));
+      assertThrows(FileNotFoundException.class, () -> fs.open(testPath));
       assertThrows(IOException.class, () -> fs.create(testPath));
-      assertThrows(FilesetPathNotFoundException.class, () -> fs.append(testPath));
+      assertThrows(FileNotFoundException.class, () -> fs.append(testPath));
 
       Path testPath1 = new Path(managedFilesetPath + "/test1.txt");
-      assertThrows(FilesetPathNotFoundException.class, () -> fs.rename(testPath, testPath1));
+      assertThrows(FileNotFoundException.class, () -> fs.rename(testPath, testPath1));
 
       assertFalse(fs.delete(testPath, true));
 
-      assertThrows(FilesetPathNotFoundException.class, () -> fs.getFileStatus(testPath));
-      assertThrows(FilesetPathNotFoundException.class, () -> fs.listStatus(testPath));
+      assertThrows(FileNotFoundException.class, () -> fs.getFileStatus(testPath));
+      assertThrows(FileNotFoundException.class, () -> fs.listStatus(testPath));
 
       assertThrows(IOException.class, () -> fs.mkdirs(testPath));
 
@@ -1009,7 +1081,10 @@ public class TestGvfsBase extends GravitinoMockServerBase {
         Assertions.assertThrows(
             IllegalArgumentException.class,
             () -> {
-              try (FileSystem fs = new Path("gvfs://fileset/").getFileSystem(configuration)) {}
+              try (FileSystem fs = new Path("gvfs://fileset/").getFileSystem(configuration)) {
+                // Trigger lazy initialization by accessing a path
+                fs.exists(new Path("gvfs://fileset/catalog/schema/fileset/file.txt"));
+              }
             });
     Assertions.assertEquals(
         "Invalid property for client: gravitino.client.xxxx", throwable.getMessage());
@@ -1035,14 +1110,395 @@ public class TestGvfsBase extends GravitinoMockServerBase {
         Assertions.assertThrows(
             RESTException.class,
             () -> {
-              try (FileSystem fs = new Path("gvfs://fileset/").getFileSystem(configuration)) {}
+              try (FileSystem fs = new Path("gvfs://fileset/").getFileSystem(configuration)) {
+                // Trigger lazy initialization by accessing a path
+                fs.exists(new Path("gvfs://fileset/catalog/schema/fileset/file.txt"));
+              }
             });
     Assertions.assertInstanceOf(SocketTimeoutException.class, throwable.getCause());
     Assertions.assertEquals("Read timed out", throwable.getCause().getMessage());
   }
 
+  @Test
+  public void testAutoCreateLocation() throws IOException, JsonProcessingException {
+    Assumptions.assumeTrue(getClass() == TestGvfsBase.class);
+    String catalogNameWithFsOpsDisabled = "catalog_fs_ops_disabled";
+    String schemaNameLocal = "schema_auto_create";
+    String filesetName = "fileset_auto_create";
+
+    // Mock a catalog with disable-filesystem-ops=true
+    CatalogDTO catalogWithFsOpsDisabled =
+        CatalogDTO.builder()
+            .withName(catalogNameWithFsOpsDisabled)
+            .withType(CatalogDTO.Type.FILESET)
+            .withProvider(provider)
+            .withComment("test catalog")
+            .withProperties(ImmutableMap.of("disable-filesystem-ops", "true"))
+            .withAudit(
+                AuditDTO.builder().withCreator("creator").withCreateTime(Instant.now()).build())
+            .build();
+    CatalogResponse catalogResponse = new CatalogResponse(catalogWithFsOpsDisabled);
+    buildMockResource(
+        Method.GET,
+        "/api/metalakes/" + metalakeName + "/catalogs/" + catalogNameWithFsOpsDisabled,
+        null,
+        catalogResponse,
+        SC_OK);
+    SchemaResponse schemaResponse =
+        new SchemaResponse(
+            SchemaDTO.builder()
+                .withName(schemaNameLocal)
+                .withAudit(AuditDTO.builder().build())
+                .withProperties(ImmutableMap.of())
+                .build());
+    buildMockResource(
+        Method.GET,
+        "/api/metalakes/"
+            + metalakeName
+            + "/catalogs/"
+            + catalogNameWithFsOpsDisabled
+            + "/schemas/"
+            + schemaNameLocal,
+        null,
+        schemaResponse,
+        SC_OK);
+
+    Path managedFilesetPath =
+        FileSystemTestUtils.createFilesetPath(
+            catalogNameWithFsOpsDisabled, schemaNameLocal, filesetName, true);
+    Path localPath =
+        FileSystemTestUtils.createLocalDirPrefix(
+            catalogNameWithFsOpsDisabled, schemaNameLocal, filesetName);
+    String locationPath =
+        String.format(
+            "/api/metalakes/%s/catalogs/%s/schemas/%s/filesets/%s/location",
+            metalakeName, catalogNameWithFsOpsDisabled, schemaNameLocal, filesetName);
+
+    // Mock the fileset
+    mockFilesetDTO(
+        metalakeName,
+        catalogNameWithFsOpsDisabled,
+        schemaNameLocal,
+        filesetName,
+        Fileset.Type.MANAGED,
+        ImmutableMap.of("location1", localPath.toString()),
+        ImmutableMap.of(PROPERTY_DEFAULT_LOCATION_NAME, "location1"));
+
+    // Test with autoCreateLocation = false
+    Configuration configWithoutAutoCreate = new Configuration(conf);
+    configWithoutAutoCreate.setBoolean(
+        GravitinoVirtualFileSystemConfiguration.FS_GRAVITINO_AUTO_CREATE_LOCATION, false);
+
+    try (FileSystem gravitinoFileSystem =
+            managedFilesetPath.getFileSystem(configWithoutAutoCreate);
+        FileSystem localFileSystem = localPath.getFileSystem(conf)) {
+
+      // Setup mock responses
+      FileLocationResponse fileLocationResponse = new FileLocationResponse(localPath.toString());
+      Map<String, String> queryParams = new HashMap<>();
+      queryParams.put("sub_path", "");
+      buildMockResource(Method.GET, locationPath, queryParams, null, fileLocationResponse, SC_OK);
+      buildMockResourceForCredential(filesetName, localPath.toString());
+
+      // Delete local path if it exists
+      if (localFileSystem.exists(localPath)) {
+        localFileSystem.delete(localPath, true);
+      }
+
+      // Verify location does not exist
+      assertFalse(localFileSystem.exists(localPath));
+
+      // Try to list the fileset - this triggers the auto-creation check
+      // When autoCreateLocation=false and directory doesn't exist, it should throw
+      // FileNotFoundException
+      assertThrows(
+          FileNotFoundException.class,
+          () -> gravitinoFileSystem.listStatus(managedFilesetPath),
+          "Should throw FileNotFoundException when location doesn't exist and autoCreateLocation=false");
+
+      // Verify location was NOT auto-created when autoCreateLocation=false
+      assertFalse(
+          localFileSystem.exists(localPath),
+          "Location should NOT be auto-created when autoCreateLocation=false");
+    }
+
+    // Test with autoCreateLocation = true (default)
+    Configuration configWithAutoCreate = new Configuration(conf);
+    // Don't set the config, use default which is true
+
+    try (FileSystem gravitinoFileSystem = managedFilesetPath.getFileSystem(configWithAutoCreate);
+        FileSystem localFileSystem = localPath.getFileSystem(conf)) {
+
+      // Setup mock responses (need to rebuild since we created a new filesystem)
+      FileLocationResponse fileLocationResponse = new FileLocationResponse(localPath.toString());
+      Map<String, String> queryParams = new HashMap<>();
+      queryParams.put("sub_path", "");
+      buildMockResource(Method.GET, locationPath, queryParams, null, fileLocationResponse, SC_OK);
+      buildMockResourceForCredential(filesetName, localPath.toString());
+
+      // Delete local path if it exists
+      if (localFileSystem.exists(localPath)) {
+        localFileSystem.delete(localPath, true);
+      }
+
+      // Verify location does not exist initially
+      assertFalse(localFileSystem.exists(localPath));
+
+      // Try to list the fileset - with autoCreateLocation=true (default), it should create the
+      // location
+      gravitinoFileSystem.listStatus(managedFilesetPath);
+
+      // Verify location WAS auto-created when autoCreateLocation=true (default)
+      assertTrue(
+          localFileSystem.exists(localPath),
+          "Location SHOULD be auto-created when autoCreateLocation=true");
+
+      // Clean up
+      localFileSystem.delete(localPath, true);
+    }
+  }
+
+  @Test
+  public void testHookSetOperationsContext() throws IOException {
+    String filesetName = "testHookSetOperationsContext";
+    Path managedFilesetPath =
+        FileSystemTestUtils.createFilesetPath(catalogName, schemaName, filesetName, true);
+    Path localPath = FileSystemTestUtils.createLocalDirPrefix(catalogName, schemaName, filesetName);
+    String locationPath =
+        String.format(
+            "/api/metalakes/%s/catalogs/%s/schemas/%s/filesets/%s/location",
+            metalakeName, catalogName, schemaName, filesetName);
+
+    try (GravitinoVirtualFileSystem fs =
+        (GravitinoVirtualFileSystem) managedFilesetPath.getFileSystem(conf)) {
+
+      // Verify that setOperationsContext was called during GVFS initialization
+      MockGVFSHook hook = getHook(fs);
+      assertTrue(
+          hook.setOperationsContextCalled,
+          "setOperationsContext should be called during initialization");
+      assertNotNull(hook.operations, "Operations context should not be null");
+      assertEquals(
+          fs.getOperations(),
+          hook.operations,
+          "Hook should have reference to the same operations instance");
+
+      // Verify the hook can access operations methods
+      FileLocationResponse fileLocationResponse = new FileLocationResponse(localPath.toString());
+      Map<String, String> queryParams = new HashMap<>();
+      queryParams.put("sub_path", "");
+      buildMockResource(Method.GET, locationPath, queryParams, null, fileLocationResponse, SC_OK);
+      buildMockResourceForCredential(filesetName, localPath.toString());
+
+      try (FileSystem localFileSystem = localPath.getFileSystem(conf)) {
+        FileSystemTestUtils.mkdirs(localPath, localFileSystem);
+        FileSystemTestUtils.mkdirs(managedFilesetPath, fs);
+
+        // Verify hook's operations context is still valid after operations are performed
+        assertNotNull(hook.operations, "Operations context should remain available");
+        assertTrue(hook.preMkdirsCalled, "Hook should be invoked for operations");
+        assertTrue(hook.postMkdirsCalled, "Hook should be invoked for operations");
+      }
+    }
+  }
+
+  @Test
+  public void testFailureHandlingMethodsAreCalled()
+      throws IOException, NoSuchFieldException, IllegalAccessException {
+    Assumptions.assumeTrue(getClass() == TestGvfsBase.class);
+    Configuration newConf = new Configuration(conf);
+    newConf.set(
+        GravitinoVirtualFileSystemConfiguration.FS_GRAVITINO_HOOK_CLASS,
+        MockGVFSHook.class.getCanonicalName());
+
+    try (GravitinoVirtualFileSystem fs =
+        (GravitinoVirtualFileSystem) new Path("gvfs://fileset/").getFileSystem(newConf)) {
+      BaseGVFSOperations mockOps = Mockito.mock(BaseGVFSOperations.class);
+
+      // Inject the mockOps
+      Field operationsField = GravitinoVirtualFileSystem.class.getDeclaredField("operations");
+      operationsField.setAccessible(true);
+      operationsField.set(fs, mockOps);
+
+      MockGVFSHook hook = getHook(fs);
+
+      // Test setWorkingDirectory failure
+      Mockito.doThrow(new RuntimeException("setWorkingDirectory failed"))
+          .when(mockOps)
+          .setWorkingDirectory(any());
+      assertThrows(
+          RuntimeException.class, () -> fs.setWorkingDirectory(new Path("gvfs://fileset/")));
+      assertTrue(
+          hook.onSetWorkingDirectoryFailureCalled, "onSetWorkingDirectoryFailure should be called");
+
+      // Test open failure
+      Mockito.doThrow(new RuntimeException("open failed")).when(mockOps).open(any(), anyInt());
+      assertThrows(RuntimeException.class, () -> fs.open(new Path("gvfs://fileset/"), 1024));
+      assertTrue(hook.onOpenFailureCalled, "onOpenFailure should be called");
+
+      // Test create failure
+      Mockito.doThrow(new RuntimeException("create failed"))
+          .when(mockOps)
+          .create(any(), any(), anyBoolean(), anyInt(), anyShort(), anyLong(), any());
+      assertThrows(RuntimeException.class, () -> fs.create(new Path("gvfs://fileset/"), true));
+      assertTrue(hook.onCreateFailureCalled, "onCreateFailure should be called");
+
+      // Test append failure
+      Mockito.doThrow(new RuntimeException("append failed"))
+          .when(mockOps)
+          .append(any(), anyInt(), any());
+      assertThrows(RuntimeException.class, () -> fs.append(new Path("gvfs://fileset/"), 1024));
+      assertTrue(hook.onAppendFailureCalled, "onAppendFailure should be called");
+
+      // Test rename failure
+      Mockito.doThrow(new RuntimeException("rename failed")).when(mockOps).rename(any(), any());
+      assertThrows(
+          RuntimeException.class,
+          () -> fs.rename(new Path("gvfs://fileset/"), new Path("gvfs://fileset/new")));
+      assertTrue(hook.onRenameFailureCalled, "onRenameFailure should be called");
+
+      // Test delete failure
+      Mockito.doThrow(new RuntimeException("delete failed"))
+          .when(mockOps)
+          .delete(any(), anyBoolean());
+      assertThrows(RuntimeException.class, () -> fs.delete(new Path("gvfs://fileset/"), true));
+      assertTrue(hook.onDeleteFailureCalled, "onDeleteFailure should be called");
+
+      // Test getFileStatus failure
+      Mockito.doThrow(new RuntimeException("getFileStatus failed"))
+          .when(mockOps)
+          .getFileStatus(any());
+      assertThrows(RuntimeException.class, () -> fs.getFileStatus(new Path("gvfs://fileset/")));
+      assertTrue(hook.onGetFileStatusFailureCalled, "onGetFileStatusFailure should be called");
+
+      // Test listStatus failure
+      Mockito.doThrow(new RuntimeException("listStatus failed")).when(mockOps).listStatus(any());
+      assertThrows(RuntimeException.class, () -> fs.listStatus(new Path("gvfs://fileset/")));
+      assertTrue(hook.onListStatusFailureCalled, "onListStatusFailure should be called");
+
+      // Test mkdirs failure
+      Mockito.doThrow(new RuntimeException("mkdirs failed")).when(mockOps).mkdirs(any(), any());
+      assertThrows(RuntimeException.class, () -> fs.mkdirs(new Path("gvfs://fileset/")));
+      assertTrue(hook.onMkdirsFailureCalled, "onMkdirsFailure should be called");
+
+      // Test getDefaultReplication failure
+      Mockito.doThrow(new RuntimeException("getDefaultReplication failed"))
+          .when(mockOps)
+          .getDefaultReplication(any());
+      assertThrows(
+          RuntimeException.class, () -> fs.getDefaultReplication(new Path("gvfs://fileset/")));
+      assertTrue(
+          hook.onGetDefaultReplicationFailureCalled,
+          "onGetDefaultReplicationFailure should be called");
+
+      // Test getDefaultBlockSize failure
+      Mockito.doThrow(new RuntimeException("getDefaultBlockSize failed"))
+          .when(mockOps)
+          .getDefaultBlockSize(any());
+      assertThrows(
+          RuntimeException.class, () -> fs.getDefaultBlockSize(new Path("gvfs://fileset/")));
+      assertTrue(
+          hook.onGetDefaultBlockSizeFailureCalled, "onGetDefaultBlockSizeFailure should be called");
+    }
+  }
+
+  @Test
+  public void testFailureHandlingWithSpecificExceptions()
+      throws IOException, NoSuchFieldException, IllegalAccessException {
+    Assumptions.assumeTrue(getClass() == TestGvfsBase.class);
+    Configuration newConf = new Configuration(conf);
+    newConf.set(
+        GravitinoVirtualFileSystemConfiguration.FS_GRAVITINO_HOOK_CLASS,
+        MockGVFSHook.class.getCanonicalName());
+
+    try (GravitinoVirtualFileSystem fs =
+        (GravitinoVirtualFileSystem) new Path("gvfs://fileset/").getFileSystem(newConf)) {
+      BaseGVFSOperations mockOps = Mockito.mock(BaseGVFSOperations.class);
+
+      // Inject the mockOps
+      Field operationsField = GravitinoVirtualFileSystem.class.getDeclaredField("operations");
+      operationsField.setAccessible(true);
+      operationsField.set(fs, mockOps);
+
+      MockGVFSHook hook = getHook(fs);
+
+      // Test with FileNotFoundException
+      Mockito.doThrow(new FileNotFoundException("File not found"))
+          .when(mockOps)
+          .open(any(), anyInt());
+      assertThrows(FileNotFoundException.class, () -> fs.open(new Path("gvfs://fileset/"), 1024));
+      assertTrue(
+          hook.onOpenFailureCalled, "onOpenFailure should be called with FileNotFoundException");
+
+      // Test with IOException
+      Mockito.doThrow(new IOException("IO error"))
+          .when(mockOps)
+          .create(any(), any(), anyBoolean(), anyInt(), anyShort(), anyLong(), any());
+      assertThrows(IOException.class, () -> fs.create(new Path("gvfs://fileset/"), true));
+      assertTrue(hook.onCreateFailureCalled, "onCreateFailure should be called with IOException");
+
+      // Test with SecurityException
+      Mockito.doThrow(new SecurityException("Security violation"))
+          .when(mockOps)
+          .delete(any(), anyBoolean());
+      assertThrows(SecurityException.class, () -> fs.delete(new Path("gvfs://fileset/"), true));
+      assertTrue(
+          hook.onDeleteFailureCalled, "onDeleteFailure should be called with SecurityException");
+    }
+  }
+
+  @Test
+  public void testFailureHandlingMethodParameters()
+      throws IOException, NoSuchFieldException, IllegalAccessException {
+    Assumptions.assumeTrue(getClass() == TestGvfsBase.class);
+    Configuration newConf = new Configuration(conf);
+    newConf.set(
+        GravitinoVirtualFileSystemConfiguration.FS_GRAVITINO_HOOK_CLASS,
+        MockGVFSHook.class.getCanonicalName());
+
+    try (GravitinoVirtualFileSystem fs =
+        (GravitinoVirtualFileSystem) new Path("gvfs://fileset/").getFileSystem(newConf)) {
+      BaseGVFSOperations mockOps = Mockito.mock(BaseGVFSOperations.class);
+
+      // Inject the mockOps
+      Field operationsField = GravitinoVirtualFileSystem.class.getDeclaredField("operations");
+      operationsField.setAccessible(true);
+      operationsField.set(fs, mockOps);
+
+      MockGVFSHook hook = getHook(fs);
+
+      Path testPath = new Path("gvfs://fileset/test");
+      RuntimeException testException = new RuntimeException("Test exception");
+
+      // Test that failure methods receive correct parameters
+      Mockito.doThrow(testException).when(mockOps).setWorkingDirectory(testPath);
+      assertThrows(RuntimeException.class, () -> fs.setWorkingDirectory(testPath));
+      assertTrue(
+          hook.onSetWorkingDirectoryFailureCalled, "onSetWorkingDirectoryFailure should be called");
+
+      // Test with specific parameters for create
+      Mockito.doThrow(testException)
+          .when(mockOps)
+          .create(eq(testPath), any(), eq(true), eq(1024), eq((short) 1), eq(128L), any());
+      assertThrows(RuntimeException.class, () -> fs.create(testPath, true, 1024, (short) 1, 128L));
+      assertTrue(
+          hook.onCreateFailureCalled, "onCreateFailure should be called with correct parameters");
+    }
+  }
+
   private void buildMockResourceForCredential(String filesetName, String filesetLocation)
       throws JsonProcessingException {
+    String schemaPath =
+        String.format(
+            "/api/metalakes/%s/catalogs/%s/schemas/%s", metalakeName, catalogName, schemaName);
+    SchemaResponse schemaResponse =
+        new SchemaResponse(
+            SchemaDTO.builder()
+                .withName(schemaName)
+                .withAudit(AuditDTO.builder().build())
+                .withProperties(ImmutableMap.of())
+                .build());
+
     String filesetPath =
         String.format(
             "/api/metalakes/%s/catalogs/%s/schemas/%s/filesets/%s",
@@ -1063,6 +1519,7 @@ public class TestGvfsBase extends GravitinoMockServerBase {
                 .build());
     CredentialResponse credentialResponse = new CredentialResponse(new CredentialDTO[] {});
 
+    buildMockResource(Method.GET, schemaPath, ImmutableMap.of(), null, schemaResponse, SC_OK);
     buildMockResource(Method.GET, filesetPath, ImmutableMap.of(), null, filesetResponse, SC_OK);
     buildMockResource(
         Method.GET, credentialsPath, ImmutableMap.of(), null, credentialResponse, SC_OK);
