@@ -99,19 +99,23 @@ public interface TableUpdateRequest extends RESTRequest {
   /** Represents a request to rename a table. */
   @EqualsAndHashCode
   @ToString
+  @Getter
   class RenameTableRequest implements TableUpdateRequest {
 
-    @Getter
     @JsonProperty("newName")
     private final String newName;
 
+    @JsonProperty("newSchemaName")
+    @Nullable
+    private final String newSchemaName;
+
     /**
      * Constructor for RenameTableRequest.
      *
      * @param newName the new name of the table
      */
     public RenameTableRequest(String newName) {
-      this.newName = newName;
+      this(newName, null);
     }
 
     /** Default constructor for Jackson deserialization. */
@@ -119,6 +123,17 @@ public interface TableUpdateRequest extends RESTRequest {
       this(null);
     }
 
+    /**
+     * Constructor for RenameTableRequest.
+     *
+     * @param newName the new name of the table
+     * @param newSchemaName the new schema name of the table, null if not changing schema
+     */
+    public RenameTableRequest(String newName, @Nullable String newSchemaName) {
+      this.newName = newName;
+      this.newSchemaName = newSchemaName;
+    }
+
     /**
      * Validates the request.
      *
@@ -137,7 +152,7 @@ public interface TableUpdateRequest extends RESTRequest {
      */
     @Override
     public TableChange tableChange() {
-      return TableChange.rename(newName);
+      return TableChange.rename(newName, newSchemaName);
     }
   }
 
@@ -265,7 +280,9 @@ public interface TableUpdateRequest extends RESTRequest {
           StringUtils.isNotBlank(property), "\"property\" field is required and cannot be empty");
     }
 
-    /** @return An instance of TableChange. */
+    /**
+     * @return An instance of TableChange.
+     */
     @Override
     public TableChange tableChange() {
       return TableChange.removeProperty(property);
@@ -387,7 +404,9 @@ public interface TableUpdateRequest extends RESTRequest {
           dataType != null, "\"type\" field is required and cannot be empty");
     }
 
-    /** @return An instance of TableChange. */
+    /**
+     * @return An instance of TableChange.
+     */
     @Override
     public TableChange tableChange() {
       return TableChange.addColumn(
@@ -441,7 +460,9 @@ public interface TableUpdateRequest extends RESTRequest {
           "\"newFieldName\" field is required and cannot be empty");
     }
 
-    /** @return An instance of TableChange. */
+    /**
+     * @return An instance of TableChange.
+     */
     @Override
     public TableChange tableChange() {
       return TableChange.renameColumn(oldFieldName, newFieldName);
@@ -496,7 +517,9 @@ public interface TableUpdateRequest extends RESTRequest {
           "\"newDefaultValue\" field is required and cannot be empty");
     }
 
-    /** @return An instance of TableChange. */
+    /**
+     * @return An instance of TableChange.
+     */
     @Override
     public TableChange tableChange() {
       return TableChange.updateColumnDefaultValue(fieldName, newDefaultValue);
@@ -550,7 +573,9 @@ public interface TableUpdateRequest extends RESTRequest {
           newType != null, "\"newType\" field is required and cannot be empty");
     }
 
-    /** @return An instance of TableChange. */
+    /**
+     * @return An instance of TableChange.
+     */
     @Override
     public TableChange tableChange() {
       return TableChange.updateColumnType(fieldName, newType);
@@ -603,7 +628,9 @@ public interface TableUpdateRequest extends RESTRequest {
           "\"newComment\" field is required and cannot be empty");
     }
 
-    /** @return An instance of TableChange. */
+    /**
+     * @return An instance of TableChange.
+     */
     @Override
     public TableChange tableChange() {
       return TableChange.updateColumnComment(fieldName, newComment);
@@ -658,7 +685,9 @@ public interface TableUpdateRequest extends RESTRequest {
           newPosition != null, "\"newPosition\" field is required and cannot be empty");
     }
 
-    /** @return An instance of TableChange. */
+    /**
+     * @return An instance of TableChange.
+     */
     @Override
     public TableChange tableChange() {
       return TableChange.updateColumnPosition(fieldName, newPosition);
@@ -762,7 +791,9 @@ public interface TableUpdateRequest extends RESTRequest {
           "\"fieldName\" field is required and cannot be empty");
     }
 
-    /** @return An instance of TableChange. */
+    /**
+     * @return An instance of TableChange.
+     */
     @Override
     public TableChange tableChange() {
       return TableChange.deleteColumn(fieldName, ifExists);
@@ -800,14 +831,16 @@ public interface TableUpdateRequest extends RESTRequest {
      */
     @Override
     public void validate() throws IllegalArgumentException {
-      Preconditions.checkNotNull(index, "Index cannot be null");
+      Preconditions.checkArgument(index != null, "Index cannot be null");
       Preconditions.checkArgument(index.type() != null, "Index type cannot be null");
       Preconditions.checkArgument(
           index.fieldNames() != null && index.fieldNames().length > 0,
           "The index must be set with corresponding column names");
     }
 
-    /** @return An instance of TableChange. */
+    /**
+     * @return An instance of TableChange.
+     */
     @Override
     public TableChange tableChange() {
       return TableChange.addIndex(index.type(), index.name(), index.fieldNames());
@@ -846,10 +879,12 @@ public interface TableUpdateRequest extends RESTRequest {
      */
     @Override
     public void validate() throws IllegalArgumentException {
-      Preconditions.checkNotNull(name, "Index name cannot be null");
+      Preconditions.checkArgument(name != null, "Index name cannot be null");
     }
 
-    /** @return An instance of TableChange. */
+    /**
+     * @return An instance of TableChange.
+     */
     @Override
     public TableChange tableChange() {
       return TableChange.deleteIndex(name, ifExists);
@@ -899,7 +934,9 @@ public interface TableUpdateRequest extends RESTRequest {
           "\"fieldName\" field is required and cannot be empty");
     }
 
-    /** @return An instance of TableChange. */
+    /**
+     * @return An instance of TableChange.
+     */
     @Override
     public TableChange tableChange() {
       return TableChange.updateColumnAutoIncrement(fieldName, autoIncrement);
