@@ -19,6 +19,7 @@
 package org.apache.gravitino.authorization;
 
 import com.google.common.base.Preconditions;
+import com.google.common.collect.ImmutableBiMap;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Sets;
 import java.util.ArrayList;
@@ -67,6 +68,36 @@ public class AuthorizationUtils {
   static final String GROUP_DOES_NOT_EXIST_MSG = "Group %s does not exist in the metalake %s";
   static final String ROLE_DOES_NOT_EXIST_MSG = "Role %s does not exist in the metalake %s";
 
+  /**
+   * Bidirectional map of deprecated privilege names to their new equivalents. This map is used for
+   * backward compatibility when handling legacy privilege names.
+   *
+   * <p>When adding new deprecated privileges, simply add an entry to this BiMap rather than adding
+   * more if-else conditions in the conversion methods.
+   *
+   * <p>This BiMap is public to allow other classes to:
+   *
+   * <ul>
+   *   <li>Check if a privilege is deprecated: {@code DEPRECATED_PRIVILEGE_MAP.containsKey(name)}
+   *   <li>Get the new equivalent: {@code DEPRECATED_PRIVILEGE_MAP.get(deprecatedName)}
+   *   <li>Get the deprecated equivalent: {@code DEPRECATED_PRIVILEGE_MAP.inverse().get(newName)}
+   * </ul>
+   */
+  @SuppressWarnings("deprecation")
+  public static final ImmutableBiMap<Privilege.Name, Privilege.Name> DEPRECATED_PRIVILEGE_MAP =
+      ImmutableBiMap.of(
+          Privilege.Name.CREATE_MODEL, Privilege.Name.REGISTER_MODEL,
+          Privilege.Name.CREATE_MODEL_VERSION, Privilege.Name.LINK_MODEL_VERSION);
+
+  private static final Set<MetadataObject.Type> SKIP_APPLY_TYPES =
+      Sets.newHashSet(
+          MetadataObject.Type.ROLE,
+          MetadataObject.Type.METALAKE,
+          MetadataObject.Type.JOB,
+          MetadataObject.Type.JOB_TEMPLATE,
+          MetadataObject.Type.TAG,
+          MetadataObject.Type.POLICY);
+
   private static final Set<Privilege.Name> FILESET_PRIVILEGES =
       Sets.immutableEnumSet(
           Privilege.Name.CREATE_FILESET, Privilege.Name.WRITE_FILESET, Privilege.Name.READ_FILESET);
@@ -79,9 +110,9 @@ public class AuthorizationUtils {
 
   private static final Set<Privilege.Name> MODEL_PRIVILEGES =
       Sets.immutableEnumSet(
-          Privilege.Name.CREATE_MODEL,
+          Privilege.Name.REGISTER_MODEL,
           Privilege.Name.USE_MODEL,
-          Privilege.Name.CREATE_MODEL_VERSION);
+          Privilege.Name.LINK_MODEL_VERSION);
 
   private AuthorizationUtils() {}
 
@@ -216,12 +247,42 @@ public class AuthorizationUtils {
   public static void checkDuplicatedNamePrivilege(Collection<Privilege> privileges) {
     Set<Privilege.Name> privilegeNameSet = Sets.newHashSet();
     for (Privilege privilege : privileges) {
-      if (privilegeNameSet.contains(privilege.name())) {
+      Privilege.Name replacePrivilegeName = replaceLegacyPrivilegeName(privilege.name());
+      if (privilegeNameSet.contains(replacePrivilegeName)) {
         throw new IllegalPrivilegeException(
             "Doesn't support duplicated privilege name %s with different condition",
             privilege.name());
       }
-      privilegeNameSet.add(privilege.name());
+      privilegeNameSet.add(replacePrivilegeName);
+    }
+  }
+
+  @SuppressWarnings("deprecation")
+  public static Privilege.Name replaceLegacyPrivilegeName(Privilege.Name privilegeName) {
+    return DEPRECATED_PRIVILEGE_MAP.getOrDefault(privilegeName, privilegeName);
+  }
+
+  public static Privilege replaceLegacyPrivilege(
+      Privilege.Name privilege, Privilege.Condition condition) {
+    Privilege.Name replacedPrivilegeName = replaceLegacyPrivilegeName(privilege);
+    if (condition == Privilege.Condition.ALLOW) {
+      return Privileges.allow(replacedPrivilegeName);
+    } else {
+      return Privileges.deny(replacedPrivilegeName);
+    }
+  }
+
+  public static Privilege getLegacyPrivilege(
+      Privilege.Name privilegeName, Privilege.Condition condition) {
+    Privilege.Name legacyPrivilegeName = DEPRECATED_PRIVILEGE_MAP.inverse().get(privilegeName);
+    if (legacyPrivilegeName == null) {
+      throw new UnsupportedOperationException(
+          "The privilege " + privilegeName + " is not a legacy privilege");
+    }
+    if (condition == Privilege.Condition.ALLOW) {
+      return Privileges.allow(legacyPrivilegeName);
+    } else {
+      return Privileges.deny(legacyPrivilegeName);
     }
   }
 
@@ -357,7 +418,7 @@ public class AuthorizationUtils {
   }
 
   private static boolean needApplyAuthorization(MetadataObject.Type type) {
-    return type != MetadataObject.Type.ROLE && type != MetadataObject.Type.METALAKE;
+    return !SKIP_APPLY_TYPES.contains(type);
   }
 
   private static void callAuthorizationPluginImpl(
