@@ -23,6 +23,7 @@ import static org.apache.gravitino.catalog.CapabilityHelpers.applyCapabilities;
 import static org.apache.gravitino.catalog.PropertiesMetadataHelpers.validatePropertyForCreate;
 import static org.apache.gravitino.rel.expressions.transforms.Transforms.EMPTY_TRANSFORM;
 import static org.apache.gravitino.utils.NameIdentifierUtil.getCatalogIdentifier;
+import static org.apache.gravitino.utils.NameIdentifierUtil.getSchemaIdentifier;
 
 import com.google.common.base.Objects;
 import com.google.common.collect.Lists;
@@ -62,7 +63,7 @@ import org.apache.gravitino.rel.expressions.transforms.Transform;
 import org.apache.gravitino.rel.indexes.Index;
 import org.apache.gravitino.rel.indexes.Indexes;
 import org.apache.gravitino.storage.IdGenerator;
-import org.apache.gravitino.utils.NameIdentifierUtil;
+import org.apache.gravitino.utils.NamespaceUtil;
 import org.apache.gravitino.utils.PrincipalUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -199,16 +200,31 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
       throws NoSuchTableException, IllegalArgumentException {
     validateAlterProperties(ident, HasPropertyMetadata::tablePropertiesMetadata, changes);
 
-    // Check if there exist TableChange.RenameTable in the changes, if so, we need to TreeLock of
-    // write on the new table name, or use the read lock on the table instead.
-    boolean containsRenameTable =
-        Arrays.stream(changes).anyMatch(c -> c instanceof TableChange.RenameTable);
-    NameIdentifier nameIdentifierForLock =
-        containsRenameTable ? NameIdentifier.of(ident.namespace().levels()) : ident;
+    // use the read lock on the table if there does not exist TableChange.RenameTable in the
+    // changes, or:
+    // 1. if the TableChange.RenameTable change the schema name, we need to acquire write lock on
+    // the catalog,
+    //    because the treeLock tool currently does not support acquiring write locks on two tables
+    // at the same time.
+    // 2. if the TableChange.RenameTable only change the table name, we need to acquire write lock
+    // to on the schema.
+    NameIdentifier nameIdentifierForLock = ident;
+    String schemaName = ident.namespace().level(2);
+    for (TableChange change : changes) {
+      if (change instanceof TableChange.RenameTable) {
+        TableChange.RenameTable rename = (TableChange.RenameTable) change;
+        if (rename.getNewSchemaName().isPresent()
+            && !rename.getNewSchemaName().get().equals(schemaName)) {
+          nameIdentifierForLock = getCatalogIdentifier(ident);
+          break;
+        }
+        nameIdentifierForLock = getSchemaIdentifier(ident);
+      }
+    }
 
     return TreeLockUtils.doWithTreeLock(
         nameIdentifierForLock,
-        LockType.WRITE,
+        nameIdentifierForLock.equals(ident) ? LockType.READ : LockType.WRITE,
         () -> {
           NameIdentifier catalogIdent = getCatalogIdentifier(ident);
           Table alteredTable =
@@ -220,6 +236,16 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
                   NoSuchTableException.class,
                   IllegalArgumentException.class);
 
+          boolean isManagedTable = isManagedEntity(catalogIdent, Capability.Scope.TABLE);
+          if (isManagedTable) {
+            return EntityCombinedTable.of(alteredTable)
+                .withHiddenProperties(
+                    getHiddenPropertyNames(
+                        getCatalogIdentifier(ident),
+                        HasPropertyMetadata::tablePropertiesMetadata,
+                        alteredTable.properties()));
+          }
+
           StringIdentifier stringId = getStringIdFromProperties(alteredTable.properties());
           // Case 1: The table is not created by Gravitino and this table is never imported.
           TableEntity te = null;
@@ -251,20 +277,16 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
                           TableEntity.class,
                           TABLE,
                           tableEntity -> {
-                            String newName =
-                                Arrays.stream(changes)
-                                    .filter(c -> c instanceof TableChange.RenameTable)
-                                    .map(c -> ((TableChange.RenameTable) c).getNewName())
-                                    .reduce((c1, c2) -> c2)
-                                    .orElse(tableEntity.name());
+                            Namespace newNamespace = getNewNamespace(ident, changes);
+
                             // Update the columns
                             Pair<Boolean, List<ColumnEntity>> columnsUpdateResult =
                                 updateColumnsIfNecessary(alteredTable, tableEntity);
 
                             return TableEntity.builder()
                                 .withId(tableEntity.id())
-                                .withName(newName)
-                                .withNamespace(ident.namespace())
+                                .withName(alteredTable.name())
+                                .withNamespace(newNamespace)
                                 .withColumns(columnsUpdateResult.getRight())
                                 .withAuditInfo(
                                     AuditInfo.builder()
@@ -298,7 +320,7 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
    */
   @Override
   public boolean dropTable(NameIdentifier ident) {
-    NameIdentifier schemaIdentifier = NameIdentifierUtil.getSchemaIdentifier(ident);
+    NameIdentifier schemaIdentifier = getSchemaIdentifier(ident);
     return TreeLockUtils.doWithTreeLock(
         schemaIdentifier,
         LockType.WRITE,
@@ -310,6 +332,11 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
                   c -> c.doWithTableOps(t -> t.dropTable(ident)),
                   RuntimeException.class);
 
+          boolean isManagedTable = isManagedEntity(catalogIdent, Capability.Scope.TABLE);
+          if (isManagedTable) {
+            return droppedFromCatalog;
+          }
+
           // For unmanaged table, it could happen that the table:
           // 1. Is not found in the catalog (dropped directly from underlying sources)
           // 2. Is found in the catalog but not in the store (not managed by Gravitino)
@@ -318,20 +345,14 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
           // In all situations, we try to delete the schema from the store, but we don't take the
           // return value of the store operation into account. We only take the return value of the
           // catalog into account.
-          //
-          // For managed table, we should take the return value of the store operation into account.
-          boolean droppedFromStore = false;
           try {
-            droppedFromStore = store.delete(ident, TABLE);
+            store.delete(ident, TABLE);
           } catch (NoSuchEntityException e) {
             LOG.warn("The table to be dropped does not exist in the store: {}", ident, e);
           } catch (Exception e) {
             throw new RuntimeException(e);
           }
-
-          return isManagedEntity(catalogIdent, Capability.Scope.TABLE)
-              ? droppedFromStore
-              : droppedFromCatalog;
+          return droppedFromCatalog;
         });
   }
 
@@ -351,7 +372,7 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
    */
   @Override
   public boolean purgeTable(NameIdentifier ident) throws UnsupportedOperationException {
-    NameIdentifier schemaIdentifier = NameIdentifierUtil.getSchemaIdentifier(ident);
+    NameIdentifier schemaIdentifier = getSchemaIdentifier(ident);
     NameIdentifier catalogIdent = getCatalogIdentifier(ident);
     return TreeLockUtils.doWithTreeLock(
         schemaIdentifier,
@@ -364,6 +385,11 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
                   RuntimeException.class,
                   UnsupportedOperationException.class);
 
+          boolean isManagedTable = isManagedEntity(catalogIdent, Capability.Scope.TABLE);
+          if (isManagedTable) {
+            return droppedFromCatalog;
+          }
+
           // For unmanaged table, it could happen that the table:
           // 1. Is not found in the catalog (dropped directly from underlying sources)
           // 2. Is found in the catalog but not in the store (not managed by Gravitino)
@@ -372,24 +398,36 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
           // In all situations, we try to delete the schema from the store, but we don't take the
           // return value of the store operation into account. We only take the return value of the
           // catalog into account.
-          //
-          // For managed table, we should take the return value of the store operation into account.
-          boolean droppedFromStore;
           try {
-            droppedFromStore = store.delete(ident, TABLE);
+            store.delete(ident, TABLE);
           } catch (NoSuchEntityException e) {
             LOG.warn("The table to be purged does not exist in the store: {}", ident, e);
             return false;
           } catch (Exception e) {
             throw new RuntimeException(e);
           }
-
-          return isManagedEntity(catalogIdent, Capability.Scope.TABLE)
-              ? droppedFromStore
-              : droppedFromCatalog;
+          return droppedFromCatalog;
         });
   }
 
+  private Namespace getNewNamespace(NameIdentifier tableIdent, TableChange... changes) {
+    String schemaName = tableIdent.namespace().level(2);
+    return Arrays.stream(changes)
+        .filter(
+            c ->
+                c instanceof TableChange.RenameTable
+                    && ((TableChange.RenameTable) c).getNewSchemaName().isPresent()
+                    && !((TableChange.RenameTable) c).getNewSchemaName().get().equals(schemaName))
+        .map(
+            c ->
+                NamespaceUtil.ofTable(
+                    tableIdent.namespace().level(0),
+                    tableIdent.namespace().level(1),
+                    ((TableChange.RenameTable) c).getNewSchemaName().get()))
+        .reduce((c1, c2) -> c2)
+        .orElse(tableIdent.namespace());
+  }
+
   private EntityCombinedTable importTable(NameIdentifier identifier) {
     EntityCombinedTable table = internalLoadTable(identifier);
 
@@ -464,6 +502,18 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
             c -> c.doWithTableOps(t -> t.loadTable(ident)),
             NoSuchTableException.class);
 
+    boolean isManagedTable = isManagedEntity(catalogIdentifier, Capability.Scope.TABLE);
+    if (isManagedTable) {
+      return EntityCombinedTable.of(table)
+          .withHiddenProperties(
+              getHiddenPropertyNames(
+                  catalogIdentifier,
+                  HasPropertyMetadata::tablePropertiesMetadata,
+                  table.properties()))
+          // The metadata of managed table is stored by Gravitino, so it is always imported.
+          .withImported(true /* imported */);
+    }
+
     StringIdentifier stringId = getStringIdFromProperties(table.properties());
     // Case 1: The table is not created by Gravitino or the external system does not support storing
     // string identifier.
@@ -488,9 +538,9 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
                   catalogIdentifier,
                   HasPropertyMetadata::tablePropertiesMetadata,
                   table.properties()))
-          // Some tables don't have properties or are not created by Gravitino,
-          // we can't use stringIdentifier to judge whether schema is ever imported or not.
-          // We need to check whether the entity exists.
+          // For some catalogs like PG, the identifier information is not stored in the table's
+          // metadata, we need to check if this table exists in the store, if so we don't
+          // need to import.
           .withImported(true);
     }
 
@@ -529,6 +579,7 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
                   return null;
                 }),
         IllegalArgumentException.class);
+
     long uid = idGenerator.nextId();
     // Add StringIdentifier to the properties, the specific catalog will handle this
     // StringIdentifier to make sure only when the operation is successful, the related
@@ -557,6 +608,15 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
             NoSuchSchemaException.class,
             TableAlreadyExistsException.class);
 
+    // If the table is managed by Gravitino, we don't need to create TableEntity and store it again.
+    boolean isManagedTable = isManagedEntity(catalogIdent, Capability.Scope.TABLE);
+    if (isManagedTable) {
+      return EntityCombinedTable.of(table)
+          .withHiddenProperties(
+              getHiddenPropertyNames(
+                  catalogIdent, HasPropertyMetadata::tablePropertiesMetadata, table.properties()));
+    }
+
     AuditInfo audit =
         AuditInfo.builder()
             .withCreator(PrincipalUtils.getCurrentPrincipal().getName())
@@ -586,6 +646,7 @@ public class TableOperationDispatcher extends OperationDispatcher implements Tab
                   catalogIdent, HasPropertyMetadata::tablePropertiesMetadata, table.properties()));
     }
 
+    // Merge both the metadata from catalog operation and the metadata from entity store.
     return EntityCombinedTable.of(table, tableEntity)
         .withHiddenProperties(
             getHiddenPropertyNames(
