@@ -56,6 +56,14 @@ import org.slf4j.LoggerFactory;
 public class PolicyManager implements PolicyDispatcher {
 
   private static final Logger LOG = LoggerFactory.getLogger(PolicyManager.class);
+  private static final Set<MetadataObject.Type> SUPPORTED_METADATA_OBJECT_TYPES_FOR_POLICIES =
+      Sets.newHashSet(
+          MetadataObject.Type.CATALOG,
+          MetadataObject.Type.SCHEMA,
+          MetadataObject.Type.TABLE,
+          MetadataObject.Type.FILESET,
+          MetadataObject.Type.TOPIC,
+          MetadataObject.Type.MODEL);
 
   private final IdGenerator idGenerator;
   private final EntityStore entityStore;
@@ -266,7 +274,8 @@ public class PolicyManager implements PolicyDispatcher {
         LockType.READ,
         () -> {
           try {
-            return entityStore.relationOperations()
+            return entityStore
+                .relationOperations()
                 .listEntitiesByRelation(
                     SupportsRelationOperations.Type.POLICY_METADATA_OBJECT_REL,
                     entityIdent,
@@ -294,9 +303,7 @@ public class PolicyManager implements PolicyDispatcher {
       String[] policiesToAdd,
       String[] policiesToRemove) {
     Preconditions.checkArgument(
-        !metadataObject.type().equals(MetadataObject.Type.METALAKE)
-            && !metadataObject.type().equals(MetadataObject.Type.ROLE)
-            && !metadataObject.type().equals(MetadataObject.Type.COLUMN),
+        SUPPORTED_METADATA_OBJECT_TYPES_FOR_POLICIES.contains(metadataObject.type()),
         "Cannot associate policies for unsupported metadata object type %s",
         metadataObject.type());
 
@@ -386,7 +393,7 @@ public class PolicyManager implements PolicyDispatcher {
                     entityType,
                     policyIdent);
           } catch (NoSuchEntityException e) {
-            if (e.getMessage().contains("No such policy entity")) {
+            if (e.getMessage().contains("No such entity")) {
               throw new NoSuchPolicyException(
                   e, "Policy %s does not exist for metadata object %s", policyName, metadataObject);
             } else {
