@@ -70,4 +70,13 @@ public interface JobTemplateMetaMapper {
   Integer updateJobTemplateMeta(
       @Param("newJobTemplateMeta") JobTemplatePO newJobTemplatePO,
       @Param("oldJobTemplateMeta") JobTemplatePO oldJobTemplatePO);
+
+  @SelectProvider(
+      type = JobTemplateMetaSQLProviderFactory.class,
+      method = "selectJobTemplateIdByMetalakeAndName")
+  Long selectJobTemplateIdByMetalakeAndName(
+      @Param("metalakeId") long metalakeId, @Param("jobTemplateName") String jobTemplateName);
+
+  @SelectProvider(type = JobTemplateMetaSQLProviderFactory.class, method = "selectJobTemplateById")
+  JobTemplatePO selectJobTemplateById(Long jobTemplateId);
 }
