@@ -141,4 +141,24 @@ public class JobTemplateMetaBaseSQLProvider {
         + " AND last_version = #{oldJobTemplateMeta.lastVersion}"
         + " AND deleted_at = 0";
   }
+
+  public String selectJobTemplateIdByMetalakeAndName(
+      @Param("metalakeId") Long metalakeId, @Param("jobTemplateName") String jobTemplateName) {
+    return "SELECT job_template_id FROM "
+        + JobTemplateMetaMapper.TABLE_NAME
+        + " WHERE deleted_at = 0 AND metalake_id = #{metalakeId} AND job_template_name = #{jobTemplateName}";
+  }
+
+  public String selectJobTemplateById(@Param("jobTemplateId") Long jobTemplateId) {
+    return "SELECT jtm.job_template_id AS jobTemplateId, jtm.job_template_name AS jobTemplateName,"
+        + " jtm.metalake_id AS metalakeId, jtm.job_template_comment AS jobTemplateComment,"
+        + " jtm.job_template_content AS jobTemplateContent, jtm.audit_info AS auditInfo,"
+        + " jtm.current_version AS currentVersion, jtm.last_version AS lastVersion,"
+        + " jtm.deleted_at AS deletedAt"
+        + " FROM "
+        + JobTemplateMetaMapper.TABLE_NAME
+        + " jtm"
+        + " WHERE jtm.job_template_id = #{jobTemplateId}"
+        + " AND jtm.deleted_at = 0";
+  }
 }
