@@ -30,8 +30,7 @@ public class FilesetVersionPostgreSQLProvider extends FilesetVersionBaseSQLProvi
   public String softDeleteFilesetVersionsByMetalakeId(Long metalakeId) {
     return "UPDATE "
         + VERSION_TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE metalake_id = #{metalakeId} AND deleted_at = 0";
   }
 
@@ -39,8 +38,7 @@ public class FilesetVersionPostgreSQLProvider extends FilesetVersionBaseSQLProvi
   public String softDeleteFilesetVersionsByCatalogId(Long catalogId) {
     return "UPDATE "
         + VERSION_TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE catalog_id = #{catalogId} AND deleted_at = 0";
   }
 
@@ -48,8 +46,7 @@ public class FilesetVersionPostgreSQLProvider extends FilesetVersionBaseSQLProvi
   public String softDeleteFilesetVersionsBySchemaId(Long schemaId) {
     return "UPDATE "
         + VERSION_TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE schema_id = #{schemaId} AND deleted_at = 0";
   }
 
@@ -57,8 +54,7 @@ public class FilesetVersionPostgreSQLProvider extends FilesetVersionBaseSQLProvi
   public String softDeleteFilesetVersionsByFilesetId(Long filesetId) {
     return "UPDATE "
         + VERSION_TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE fileset_id = #{filesetId} AND deleted_at = 0";
   }
 
@@ -77,8 +73,7 @@ public class FilesetVersionPostgreSQLProvider extends FilesetVersionBaseSQLProvi
       Long filesetId, long versionRetentionLine, int limit) {
     return "UPDATE "
         + VERSION_TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE id IN (SELECT id FROM "
         + VERSION_TABLE_NAME
         + " WHERE fileset_id = #{filesetId} AND version <= #{versionRetentionLine} AND deleted_at = 0 LIMIT #{limit})";
