@@ -31,8 +31,7 @@ public class PolicyVersionPostgreSQLProvider extends PolicyVersionBaseSQLProvide
       String metalakeName, String policyName) {
     return "UPDATE "
         + POLICY_VERSION_TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE metalake_id = (SELECT metalake_id FROM "
         + MetalakeMetaMapper.TABLE_NAME
         + " mm WHERE mm.metalake_name = #{metalakeName} AND mm.deleted_at = 0)"
@@ -56,11 +55,10 @@ public class PolicyVersionPostgreSQLProvider extends PolicyVersionBaseSQLProvide
       Long policyId, long versionRetentionLine, int limit) {
     return "UPDATE "
         + POLICY_VERSION_TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE id IN (SELECT id FROM "
         + POLICY_VERSION_TABLE_NAME
-        + " WHERE policy_id = #{policyId} AND version < #{versionRetentionLine}"
+        + " WHERE policy_id = #{policyId} AND version <= #{versionRetentionLine}"
         + " AND deleted_at = 0 LIMIT #{limit})";
   }
 
@@ -68,8 +66,7 @@ public class PolicyVersionPostgreSQLProvider extends PolicyVersionBaseSQLProvide
   public String softDeletePolicyVersionsByMetalakeId(Long metalakeId) {
     return "UPDATE "
         + POLICY_VERSION_TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE metalake_id = #{metalakeId} AND deleted_at = 0";
   }
 
