@@ -29,10 +29,10 @@ public class TableMetaPostgreSQLProvider extends TableMetaBaseSQLProvider {
   public String insertTableMetaOnDuplicateKeyUpdate(TablePO tablePO) {
     return "INSERT INTO "
         + TABLE_NAME
-        + "(table_id, table_name, metalake_id,"
+        + " (table_id, table_name, metalake_id,"
         + " catalog_id, schema_id, audit_info,"
         + " current_version, last_version, deleted_at)"
-        + " VALUES("
+        + " VALUES ("
         + " #{tableMeta.tableId},"
         + " #{tableMeta.tableName},"
         + " #{tableMeta.metalakeId},"
@@ -43,7 +43,7 @@ public class TableMetaPostgreSQLProvider extends TableMetaBaseSQLProvider {
         + " #{tableMeta.lastVersion},"
         + " #{tableMeta.deletedAt}"
         + " )"
-        + " ON CONFLICT (table_id) DO UPDATE SET "
+        + " ON CONFLICT (table_id) DO UPDATE SET"
         + " table_name = #{tableMeta.tableName},"
         + " metalake_id = #{tableMeta.metalakeId},"
         + " catalog_id = #{tableMeta.catalogId},"
@@ -58,8 +58,7 @@ public class TableMetaPostgreSQLProvider extends TableMetaBaseSQLProvider {
   public String softDeleteTableMetasByTableId(Long tableId) {
     return "UPDATE "
         + TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE table_id = #{tableId} AND deleted_at = 0";
   }
 
@@ -67,8 +66,7 @@ public class TableMetaPostgreSQLProvider extends TableMetaBaseSQLProvider {
   public String softDeleteTableMetasByMetalakeId(Long metalakeId) {
     return "UPDATE "
         + TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE metalake_id = #{metalakeId} AND deleted_at = 0";
   }
 
@@ -76,8 +74,7 @@ public class TableMetaPostgreSQLProvider extends TableMetaBaseSQLProvider {
   public String softDeleteTableMetasByCatalogId(Long catalogId) {
     return "UPDATE "
         + TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE catalog_id = #{catalogId} AND deleted_at = 0";
   }
 
@@ -85,8 +82,7 @@ public class TableMetaPostgreSQLProvider extends TableMetaBaseSQLProvider {
   public String softDeleteTableMetasBySchemaId(Long schemaId) {
     return "UPDATE "
         + TABLE_NAME
-        + " SET deleted_at = floor(extract(epoch from(current_timestamp -"
-        + " timestamp '1970-01-01 00:00:00'))*1000)"
+        + " SET deleted_at = CAST(EXTRACT(EPOCH FROM CURRENT_TIMESTAMP) * 1000 AS BIGINT)"
         + " WHERE schema_id = #{schemaId} AND deleted_at = 0";
   }
 
