@@ -18,6 +18,8 @@
  */
 package org.apache.gravitino.storage.relational.service;
 
+import static org.apache.gravitino.metrics.source.MetricsSource.GRAVITINO_RELATIONAL_STORE_METRIC_NAME;
+
 import com.google.common.base.Preconditions;
 import java.io.IOException;
 import java.util.List;
@@ -32,6 +34,7 @@ import org.apache.gravitino.NameIdentifier;
 import org.apache.gravitino.Namespace;
 import org.apache.gravitino.exceptions.NoSuchEntityException;
 import org.apache.gravitino.meta.JobTemplateEntity;
+import org.apache.gravitino.metrics.Monitored;
 import org.apache.gravitino.storage.relational.mapper.JobMetaMapper;
 import org.apache.gravitino.storage.relational.mapper.JobTemplateMetaMapper;
 import org.apache.gravitino.storage.relational.po.JobTemplatePO;
@@ -50,6 +53,9 @@ public class JobTemplateMetaService {
     return INSTANCE;
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "listJobTemplatesByNamespace")
   public List<JobTemplateEntity> listJobTemplatesByNamespace(Namespace ns) {
     String metalakeName = ns.level(0);
     List<JobTemplatePO> jobTemplatePOs =
@@ -62,18 +68,24 @@ public class JobTemplateMetaService {
         .collect(Collectors.toList());
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "getJobTemplateByIdentifier")
   public JobTemplateEntity getJobTemplateByIdentifier(NameIdentifier jobTemplateIdent) {
     JobTemplatePO jobTemplatePO = getJobTemplatePO(jobTemplateIdent);
     return JobTemplatePO.fromJobTemplatePO(jobTemplatePO, jobTemplateIdent.namespace());
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "insertJobTemplate")
   public void insertJobTemplate(JobTemplateEntity jobTemplateEntity, boolean overwrite)
       throws IOException {
     String metalakeName = jobTemplateEntity.namespace().level(0);
 
     try {
-      Long metalakeId = MetalakeMetaService.getInstance().getMetalakeIdByName(metalakeName);
-
+      Long metalakeId =
+          EntityIdService.getEntityId(NameIdentifier.of(metalakeName), Entity.EntityType.METALAKE);
       JobTemplatePO.JobTemplatePOBuilder builder =
           JobTemplatePO.builder().withMetalakeId(metalakeId);
       JobTemplatePO jobTemplatePO =
@@ -94,6 +106,9 @@ public class JobTemplateMetaService {
     }
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "deleteJobTemplate")
   public boolean deleteJobTemplate(NameIdentifier jobTemplateIdent) {
     String metalakeName = jobTemplateIdent.namespace().level(0);
     String jobTemplateName = jobTemplateIdent.name();
@@ -115,12 +130,18 @@ public class JobTemplateMetaService {
     return result.get() > 0;
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "deleteJobTemplatesByLegacyTimeline")
   public int deleteJobTemplatesByLegacyTimeline(long legacyTimeline, int limit) {
     return SessionUtils.doWithCommitAndFetchResult(
         JobTemplateMetaMapper.class,
         mapper -> mapper.deleteJobTemplateMetasByLegacyTimeline(legacyTimeline, limit));
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "updateJobTemplate")
   public <E extends Entity & HasIdentifier> JobTemplateEntity updateJobTemplate(
       NameIdentifier jobTemplateIdent, Function<E, E> updater) throws IOException {
     JobTemplatePO oldJobTemplatePO = getJobTemplatePO(jobTemplateIdent);
@@ -183,4 +204,19 @@ public class JobTemplateMetaService {
     }
     return jobTemplatePO;
   }
+
+  public long getJobTemplateIdByMetalakeIdAndName(long metalakeId, String name) {
+    Long jobTemplateId =
+        SessionUtils.getWithoutCommit(
+            JobTemplateMetaMapper.class,
+            mapper -> mapper.selectJobTemplateIdByMetalakeAndName(metalakeId, name));
+
+    if (jobTemplateId == null) {
+      throw new NoSuchEntityException(
+          NoSuchEntityException.NO_SUCH_ENTITY_MESSAGE,
+          Entity.EntityType.JOB_TEMPLATE.name().toLowerCase(Locale.ROOT),
+          name);
+    }
+    return jobTemplateId;
+  }
 }
