@@ -19,6 +19,8 @@
 
 package org.apache.gravitino.storage.relational.service;
 
+import static org.apache.gravitino.metrics.source.MetricsSource.GRAVITINO_RELATIONAL_STORE_METRIC_NAME;
+
 import com.google.common.base.Preconditions;
 import java.io.IOException;
 import java.util.List;
@@ -34,6 +36,8 @@ import org.apache.gravitino.NameIdentifier;
 import org.apache.gravitino.Namespace;
 import org.apache.gravitino.exceptions.NoSuchEntityException;
 import org.apache.gravitino.meta.ModelEntity;
+import org.apache.gravitino.meta.NamespacedEntityId;
+import org.apache.gravitino.metrics.Monitored;
 import org.apache.gravitino.storage.relational.mapper.ModelMetaMapper;
 import org.apache.gravitino.storage.relational.mapper.ModelVersionAliasRelMapper;
 import org.apache.gravitino.storage.relational.mapper.ModelVersionMetaMapper;
@@ -63,10 +67,14 @@ public class ModelMetaService {
 
   private ModelMetaService() {}
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "listModelsByNamespace")
   public List<ModelEntity> listModelsByNamespace(Namespace ns) {
     NamespaceUtil.checkModel(ns);
 
-    Long schemaId = CommonMetaService.getInstance().getParentEntityIdByNamespace(ns);
+    Long schemaId =
+        EntityIdService.getEntityId(NameIdentifier.of(ns.levels()), Entity.EntityType.SCHEMA);
 
     List<ModelPO> modelPOs =
         SessionUtils.getWithoutCommit(
@@ -75,11 +83,15 @@ public class ModelMetaService {
     return modelPOs.stream().map(m -> POConverters.fromModelPO(m, ns)).collect(Collectors.toList());
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "getModelByIdentifier")
   public ModelEntity getModelByIdentifier(NameIdentifier ident) {
     ModelPO modelPO = getModelPOByIdentifier(ident);
     return POConverters.fromModelPO(modelPO, ident.namespace());
   }
 
+  @Monitored(metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME, baseMetricName = "insertModel")
   public void insertModel(ModelEntity modelEntity, boolean overwrite) throws IOException {
     NameIdentifierUtil.checkModel(modelEntity.nameIdentifier());
 
@@ -104,13 +116,16 @@ public class ModelMetaService {
     }
   }
 
+  @Monitored(metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME, baseMetricName = "deleteModel")
   public boolean deleteModel(NameIdentifier ident) {
     NameIdentifierUtil.checkModel(ident);
 
     Long schemaId;
     Long modelId;
     try {
-      schemaId = CommonMetaService.getInstance().getParentEntityIdByNamespace(ident.namespace());
+      schemaId =
+          EntityIdService.getEntityId(
+              NameIdentifier.of(ident.namespace().levels()), Entity.EntityType.SCHEMA);
       modelId = getModelIdBySchemaIdAndModelName(schemaId, ident.name());
     } catch (NoSuchEntityException e) {
       LOG.warn("Failed to delete model: {}", ident, e);
@@ -173,13 +188,19 @@ public class ModelMetaService {
     return modelDeletedCount.get() > 0;
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "deleteModelMetasByLegacyTimeline")
   public int deleteModelMetasByLegacyTimeline(Long legacyTimeline, int limit) {
     return SessionUtils.doWithCommitAndFetchResult(
         ModelMetaMapper.class,
         mapper -> mapper.deleteModelMetasByLegacyTimeline(legacyTimeline, limit));
   }
 
-  Long getModelIdBySchemaIdAndModelName(Long schemaId, String modelName) {
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "getModelIdBySchemaIdAndModelName")
+  public Long getModelIdBySchemaIdAndModelName(Long schemaId, String modelName) {
     Long modelId =
         SessionUtils.getWithoutCommit(
             ModelMetaMapper.class,
@@ -195,6 +216,9 @@ public class ModelMetaService {
     return modelId;
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "getModelPOById")
   ModelPO getModelPOById(Long modelId) {
     ModelPO modelPO =
         SessionUtils.getWithoutCommit(
@@ -212,16 +236,22 @@ public class ModelMetaService {
 
   private void fillModelPOBuilderParentEntityId(ModelPO.Builder builder, Namespace ns) {
     NamespaceUtil.checkModel(ns);
-    Long[] parentEntityIds = CommonMetaService.getInstance().getParentEntityIdsByNamespace(ns);
-    builder.withMetalakeId(parentEntityIds[0]);
-    builder.withCatalogId(parentEntityIds[1]);
-    builder.withSchemaId(parentEntityIds[2]);
+    NamespacedEntityId namespacedEntityId =
+        EntityIdService.getEntityIds(NameIdentifier.of(ns.levels()), Entity.EntityType.SCHEMA);
+    builder.withMetalakeId(namespacedEntityId.namespaceIds()[0]);
+    builder.withCatalogId(namespacedEntityId.namespaceIds()[1]);
+    builder.withSchemaId(namespacedEntityId.entityId());
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "getModelPOByIdentifier")
   ModelPO getModelPOByIdentifier(NameIdentifier ident) {
     NameIdentifierUtil.checkModel(ident);
 
-    Long schemaId = CommonMetaService.getInstance().getParentEntityIdByNamespace(ident.namespace());
+    Long schemaId =
+        EntityIdService.getEntityId(
+            NameIdentifier.of(ident.namespace().levels()), Entity.EntityType.SCHEMA);
 
     ModelPO modelPO =
         SessionUtils.getWithoutCommit(
@@ -237,6 +267,7 @@ public class ModelMetaService {
     return modelPO;
   }
 
+  @Monitored(metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME, baseMetricName = "updateModel")
   public <E extends Entity & HasIdentifier> ModelEntity updateModel(
       NameIdentifier identifier, Function<E, E> updater) throws IOException {
     NameIdentifierUtil.checkModel(identifier);
