@@ -18,6 +18,8 @@
  */
 package org.apache.gravitino.storage.relational.service;
 
+import static org.apache.gravitino.metrics.source.MetricsSource.GRAVITINO_RELATIONAL_STORE_METRIC_NAME;
+
 import com.google.common.base.Preconditions;
 import com.google.common.collect.ArrayListMultimap;
 import com.google.common.collect.ImmutableList;
@@ -40,6 +42,7 @@ import org.apache.gravitino.Namespace;
 import org.apache.gravitino.exceptions.NoSuchEntityException;
 import org.apache.gravitino.meta.ModelEntity;
 import org.apache.gravitino.meta.ModelVersionEntity;
+import org.apache.gravitino.metrics.Monitored;
 import org.apache.gravitino.storage.relational.mapper.ModelMetaMapper;
 import org.apache.gravitino.storage.relational.mapper.ModelVersionAliasRelMapper;
 import org.apache.gravitino.storage.relational.mapper.ModelVersionMetaMapper;
@@ -61,6 +64,9 @@ public class ModelVersionMetaService {
 
   private ModelVersionMetaService() {}
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "listModelVersionsByNamespace")
   public List<ModelVersionEntity> listModelVersionsByNamespace(Namespace ns) {
     NamespaceUtil.checkModelVersion(ns);
 
@@ -102,6 +108,9 @@ public class ModelVersionMetaService {
             .values());
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "getModelVersionByIdentifier")
   public ModelVersionEntity getModelVersionByIdentifier(NameIdentifier ident) {
     NameIdentifierUtil.checkModelVersion(ident);
 
@@ -146,15 +155,14 @@ public class ModelVersionMetaService {
     return POConverters.fromModelVersionPO(modelIdent, modelVersionPOs, aliasRelPOs);
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "insertModelVersion")
   public void insertModelVersion(ModelVersionEntity modelVersionEntity) throws IOException {
     NameIdentifier modelIdent = modelVersionEntity.modelIdentifier();
     NameIdentifierUtil.checkModel(modelIdent);
 
-    Long schemaId =
-        CommonMetaService.getInstance().getParentEntityIdByNamespace(modelIdent.namespace());
-    Long modelId =
-        ModelMetaService.getInstance()
-            .getModelIdBySchemaIdAndModelName(schemaId, modelIdent.name());
+    Long modelId = EntityIdService.getEntityId(modelIdent, Entity.EntityType.MODEL);
 
     List<ModelVersionPO> modelVersionPOs =
         POConverters.initializeModelVersionPO(modelVersionEntity, modelId);
@@ -186,6 +194,9 @@ public class ModelVersionMetaService {
     }
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "deleteModelVersion")
   public boolean deleteModelVersion(NameIdentifier ident) {
     NameIdentifierUtil.checkModelVersion(ident);
 
@@ -238,6 +249,9 @@ public class ModelVersionMetaService {
     return modelVersionDeletedCount.get() > 0;
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "deleteModelVersionMetasByLegacyTimeline")
   public int deleteModelVersionMetasByLegacyTimeline(Long legacyTimeline, int limit) {
     int[] modelVersionDeletedCount = new int[] {0};
     int[] modelVersionAliasRelDeletedCount = new int[] {0};
@@ -268,6 +282,9 @@ public class ModelVersionMetaService {
    * @param <E> the type of the entity to update
    * @throws IOException if an error occurs while updating the entity
    */
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "updateModelVersion")
   public <E extends Entity & HasIdentifier> ModelVersionEntity updateModelVersion(
       NameIdentifier ident, Function<E, E> updater) throws IOException {
     NameIdentifierUtil.checkModelVersion(ident);
@@ -384,7 +401,7 @@ public class ModelVersionMetaService {
 
     } catch (RuntimeException re) {
       ExceptionUtils.checkSQLException(
-          re, Entity.EntityType.CATALOG, newModelVersionEntity.nameIdentifier().toString());
+          re, Entity.EntityType.MODEL_VERSION, newModelVersionEntity.nameIdentifier().toString());
       throw re;
     }
 
