@@ -18,6 +18,8 @@
  */
 package org.apache.gravitino.storage.relational.service;
 
+import static org.apache.gravitino.metrics.source.MetricsSource.GRAVITINO_RELATIONAL_STORE_METRIC_NAME;
+
 import com.google.common.collect.Lists;
 import java.util.Collections;
 import java.util.List;
@@ -29,6 +31,7 @@ import org.apache.gravitino.Entity;
 import org.apache.gravitino.exceptions.NoSuchEntityException;
 import org.apache.gravitino.meta.ColumnEntity;
 import org.apache.gravitino.meta.TableEntity;
+import org.apache.gravitino.metrics.Monitored;
 import org.apache.gravitino.storage.relational.mapper.TableColumnMapper;
 import org.apache.gravitino.storage.relational.po.ColumnPO;
 import org.apache.gravitino.storage.relational.po.TablePO;
@@ -45,6 +48,9 @@ public class TableColumnMetaService {
     return INSTANCE;
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "getColumnsByTableIdAndVersion")
   List<ColumnPO> getColumnsByTableIdAndVersion(Long tableId, Long version) {
     List<ColumnPO> columnPOs =
         SessionUtils.getWithoutCommit(
@@ -57,7 +63,10 @@ public class TableColumnMetaService {
         .collect(Collectors.toList());
   }
 
-  Long getColumnIdByTableIdAndName(Long tableId, String columnName) {
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "getColumnIdByTableIdAndName")
+  public Long getColumnIdByTableIdAndName(Long tableId, String columnName) {
     Long columnId =
         SessionUtils.getWithoutCommit(
             TableColumnMapper.class,
@@ -73,6 +82,9 @@ public class TableColumnMetaService {
     return columnId;
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "getColumnPOById")
   ColumnPO getColumnPOById(Long columnId) {
     ColumnPO columnPO =
         SessionUtils.getWithoutCommit(
@@ -88,6 +100,9 @@ public class TableColumnMetaService {
     return columnPO;
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "insertColumnPOs")
   void insertColumnPOs(TablePO tablePO, List<ColumnEntity> columnEntities) {
     List<ColumnPO> columnPOs =
         POConverters.initializeColumnPOs(tablePO, columnEntities, ColumnPO.ColumnOpType.CREATE);
@@ -97,6 +112,9 @@ public class TableColumnMetaService {
         TableColumnMapper.class, mapper -> mapper.insertColumnPOs(columnPOs));
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "deleteColumnsByTableId")
   boolean deleteColumnsByTableId(Long tableId) {
     // deleteColumns will be done in deleteTable transaction, so we don't do commit here.
     Integer result =
@@ -105,6 +123,9 @@ public class TableColumnMetaService {
     return result > 0;
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "deleteColumnsByLegacyTimeline")
   public int deleteColumnsByLegacyTimeline(Long legacyTimeline, int limit) {
     return SessionUtils.doWithCommitAndFetchResult(
         TableColumnMapper.class,
@@ -127,6 +148,9 @@ public class TableColumnMetaService {
     return oldColumns.size() != newColumns.size() || !oldColumns.equals(newColumns);
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "updateColumnPOsFromTableDiff")
   void updateColumnPOsFromTableDiff(
       TableEntity oldTable, TableEntity newTable, TablePO newTablePO) {
     Map<Long, ColumnEntity> oldColumns =
@@ -160,6 +184,13 @@ public class TableColumnMetaService {
 
     // If there is no change, directly return
     if (columnPOsToInsert.isEmpty()) {
+      // If namespace is changed, just update the schema_id of the columns.
+      if (!newTable.namespace().equals(oldTable.namespace())) {
+        SessionUtils.doWithoutCommit(
+            TableColumnMapper.class,
+            mapper ->
+                mapper.updateSchemaIdByTableId(newTablePO.getTableId(), newTablePO.getSchemaId()));
+      }
       return;
     }
 
