@@ -18,6 +18,8 @@
  */
 package org.apache.gravitino.storage.relational.service;
 
+import static org.apache.gravitino.metrics.source.MetricsSource.GRAVITINO_RELATIONAL_STORE_METRIC_NAME;
+
 import com.google.common.base.Preconditions;
 import java.io.IOException;
 import java.util.List;
@@ -31,12 +33,15 @@ import org.apache.gravitino.MetadataObject;
 import org.apache.gravitino.NameIdentifier;
 import org.apache.gravitino.Namespace;
 import org.apache.gravitino.exceptions.NoSuchEntityException;
+import org.apache.gravitino.meta.NamespacedEntityId;
 import org.apache.gravitino.meta.TableEntity;
+import org.apache.gravitino.metrics.Monitored;
 import org.apache.gravitino.storage.relational.mapper.OwnerMetaMapper;
 import org.apache.gravitino.storage.relational.mapper.PolicyMetadataObjectRelMapper;
 import org.apache.gravitino.storage.relational.mapper.SecurableObjectMapper;
 import org.apache.gravitino.storage.relational.mapper.StatisticMetaMapper;
 import org.apache.gravitino.storage.relational.mapper.TableMetaMapper;
+import org.apache.gravitino.storage.relational.mapper.TableVersionMapper;
 import org.apache.gravitino.storage.relational.mapper.TagMetadataObjectRelMapper;
 import org.apache.gravitino.storage.relational.po.ColumnPO;
 import org.apache.gravitino.storage.relational.po.TablePO;
@@ -56,14 +61,9 @@ public class TableMetaService {
 
   private TableMetaService() {}
 
-  // Table may be deleted, so the TablePO may be null.
-  public TablePO getTablePOById(Long tableId) {
-    TablePO tablePO =
-        SessionUtils.getWithoutCommit(
-            TableMetaMapper.class, mapper -> mapper.selectTableMetaById(tableId));
-    return tablePO;
-  }
-
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "getTableIdBySchemaIdAndName")
   public Long getTableIdBySchemaIdAndName(Long schemaId, String tableName) {
     Long tableId =
         SessionUtils.getWithoutCommit(
@@ -79,11 +79,15 @@ public class TableMetaService {
     return tableId;
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "getTableByIdentifier")
   public TableEntity getTableByIdentifier(NameIdentifier identifier) {
     NameIdentifierUtil.checkTable(identifier);
 
     Long schemaId =
-        CommonMetaService.getInstance().getParentEntityIdByNamespace(identifier.namespace());
+        EntityIdService.getEntityId(
+            NameIdentifier.of(identifier.namespace().levels()), Entity.EntityType.SCHEMA);
 
     TablePO tablePO = getTablePOBySchemaIdAndName(schemaId, identifier.name());
     List<ColumnPO> columnPOs =
@@ -93,10 +97,15 @@ public class TableMetaService {
     return POConverters.fromTableAndColumnPOs(tablePO, columnPOs, identifier.namespace());
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "listTablesByNamespace")
   public List<TableEntity> listTablesByNamespace(Namespace namespace) {
     NamespaceUtil.checkTable(namespace);
 
-    Long schemaId = CommonMetaService.getInstance().getParentEntityIdByNamespace(namespace);
+    Long schemaId =
+        EntityIdService.getEntityId(
+            NameIdentifier.of(namespace.levels()), Entity.EntityType.SCHEMA);
 
     List<TablePO> tablePOs =
         SessionUtils.getWithoutCommit(
@@ -105,6 +114,7 @@ public class TableMetaService {
     return POConverters.fromTablePOs(tablePOs, namespace);
   }
 
+  @Monitored(metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME, baseMetricName = "insertTable")
   public void insertTable(TableEntity tableEntity, boolean overwrite) throws IOException {
     try {
       NameIdentifierUtil.checkTable(tableEntity.nameIdentifier());
@@ -113,12 +123,12 @@ public class TableMetaService {
       fillTablePOBuilderParentEntityId(builder, tableEntity.namespace());
 
       AtomicReference<TablePO> tablePORef = new AtomicReference<>();
+      TablePO po = POConverters.initializeTablePOWithVersion(tableEntity, builder);
       SessionUtils.doMultipleWithCommit(
           () ->
               SessionUtils.doWithoutCommit(
                   TableMetaMapper.class,
                   mapper -> {
-                    TablePO po = POConverters.initializeTablePOWithVersion(tableEntity, builder);
                     tablePORef.set(po);
                     if (overwrite) {
                       mapper.insertTableMetaOnDuplicateKeyUpdate(po);
@@ -126,6 +136,16 @@ public class TableMetaService {
                       mapper.insertTableMeta(po);
                     }
                   }),
+          () ->
+              SessionUtils.doWithoutCommit(
+                  TableVersionMapper.class,
+                  mapper -> {
+                    if (overwrite) {
+                      mapper.insertTableVersionOnDuplicateKeyUpdate(po);
+                    } else {
+                      mapper.insertTableVersion(po);
+                    }
+                  }),
           () -> {
             // We need to delete the columns first if we want to overwrite the table.
             if (overwrite) {
@@ -147,6 +167,7 @@ public class TableMetaService {
     }
   }
 
+  @Monitored(metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME, baseMetricName = "updateTable")
   public <E extends Entity & HasIdentifier> TableEntity updateTable(
       NameIdentifier identifier, Function<E, E> updater) throws IOException {
     NameIdentifierUtil.checkTable(identifier);
@@ -154,7 +175,8 @@ public class TableMetaService {
     String tableName = identifier.name();
 
     Long schemaId =
-        CommonMetaService.getInstance().getParentEntityIdByNamespace(identifier.namespace());
+        EntityIdService.getEntityId(
+            NameIdentifier.of(identifier.namespace().levels()), Entity.EntityType.SCHEMA);
 
     TablePO oldTablePO = getTablePOBySchemaIdAndName(schemaId, tableName);
     List<ColumnPO> oldTableColumns =
@@ -170,10 +192,15 @@ public class TableMetaService {
         newTableEntity.id(),
         oldTableEntity.id());
 
-    boolean isColumnChanged =
-        TableColumnMetaService.getInstance().isColumnUpdated(oldTableEntity, newTableEntity);
+    boolean isSchemaChanged = !newTableEntity.namespace().equals(oldTableEntity.namespace());
+    Long newSchemaId =
+        isSchemaChanged
+            ? EntityIdService.getEntityId(
+                NameIdentifier.of(newTableEntity.namespace().levels()), Entity.EntityType.SCHEMA)
+            : schemaId;
+
     TablePO newTablePO =
-        POConverters.updateTablePOWithVersion(oldTablePO, newTableEntity, isColumnChanged);
+        POConverters.updateTablePOWithVersionAndSchemaId(oldTablePO, newTableEntity, newSchemaId);
 
     final AtomicInteger updateResult = new AtomicInteger(0);
     try {
@@ -182,9 +209,17 @@ public class TableMetaService {
               updateResult.set(
                   SessionUtils.getWithoutCommit(
                       TableMetaMapper.class,
-                      mapper -> mapper.updateTableMeta(newTablePO, oldTablePO))),
+                      mapper -> mapper.updateTableMeta(newTablePO, oldTablePO, newSchemaId))),
+          () ->
+              SessionUtils.doWithoutCommit(
+                  TableVersionMapper.class,
+                  mapper -> {
+                    mapper.softDeleteTableVersionByTableIdAndVersion(
+                        oldTablePO.getTableId(), oldTablePO.getCurrentVersion());
+                    mapper.insertTableVersionOnDuplicateKeyUpdate(newTablePO);
+                  }),
           () -> {
-            if (updateResult.get() > 0 && isColumnChanged) {
+            if (updateResult.get() > 0) {
               TableColumnMetaService.getInstance()
                   .updateColumnPOsFromTableDiff(oldTableEntity, newTableEntity, newTablePO);
             }
@@ -203,70 +238,95 @@ public class TableMetaService {
     }
   }
 
+  @Monitored(metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME, baseMetricName = "deleteTable")
   public boolean deleteTable(NameIdentifier identifier) {
     NameIdentifierUtil.checkTable(identifier);
 
-    String tableName = identifier.name();
-
-    Long schemaId =
-        CommonMetaService.getInstance().getParentEntityIdByNamespace(identifier.namespace());
-
-    Long tableId = getTableIdBySchemaIdAndName(schemaId, tableName);
+    NamespacedEntityId namespacedEntityId =
+        EntityIdService.getEntityIds(identifier, Entity.EntityType.TABLE);
 
     AtomicInteger deleteResult = new AtomicInteger(0);
+    TablePO[] tablePOHolder = new TablePO[1];
     SessionUtils.doMultipleWithCommit(
+        () -> {
+          tablePOHolder[0] =
+              getTablePOBySchemaIdAndName(namespacedEntityId.namespaceIds()[2], identifier.name());
+        },
         () ->
             deleteResult.set(
                 SessionUtils.getWithoutCommit(
                     TableMetaMapper.class,
-                    mapper -> mapper.softDeleteTableMetasByTableId(tableId))),
+                    mapper -> mapper.softDeleteTableMetasByTableId(namespacedEntityId.entityId()))),
         () -> {
           if (deleteResult.get() > 0) {
             SessionUtils.doWithoutCommit(
                 OwnerMetaMapper.class,
                 mapper ->
                     mapper.softDeleteOwnerRelByMetadataObjectIdAndType(
-                        tableId, MetadataObject.Type.TABLE.name()));
-            TableColumnMetaService.getInstance().deleteColumnsByTableId(tableId);
+                        namespacedEntityId.entityId(), MetadataObject.Type.TABLE.name()));
+            TableColumnMetaService.getInstance()
+                .deleteColumnsByTableId(namespacedEntityId.entityId());
             SessionUtils.doWithoutCommit(
                 SecurableObjectMapper.class,
                 mapper ->
                     mapper.softDeleteObjectRelsByMetadataObject(
-                        tableId, MetadataObject.Type.TABLE.name()));
+                        namespacedEntityId.entityId(), MetadataObject.Type.TABLE.name()));
             SessionUtils.doWithoutCommit(
                 TagMetadataObjectRelMapper.class,
                 mapper ->
                     mapper.softDeleteTagMetadataObjectRelsByMetadataObject(
-                        tableId, MetadataObject.Type.TABLE.name()));
+                        namespacedEntityId.entityId(), MetadataObject.Type.TABLE.name()));
             SessionUtils.doWithoutCommit(
                 TagMetadataObjectRelMapper.class,
-                mapper -> mapper.softDeleteTagMetadataObjectRelsByTableId(tableId));
+                mapper ->
+                    mapper.softDeleteTagMetadataObjectRelsByTableId(namespacedEntityId.entityId()));
 
             SessionUtils.doWithoutCommit(
                 StatisticMetaMapper.class,
-                mapper -> mapper.softDeleteStatisticsByEntityId(tableId));
+                mapper -> mapper.softDeleteStatisticsByEntityId(namespacedEntityId.entityId()));
             SessionUtils.doWithoutCommit(
                 PolicyMetadataObjectRelMapper.class,
-                mapper -> mapper.softDeletePolicyMetadataObjectRelsByTableId(tableId));
+                mapper ->
+                    mapper.softDeletePolicyMetadataObjectRelsByTableId(
+                        namespacedEntityId.entityId()));
+            SessionUtils.doWithoutCommit(
+                TableVersionMapper.class,
+                mapper ->
+                    mapper.softDeleteTableVersionByTableIdAndVersion(
+                        namespacedEntityId.entityId(), tablePOHolder[0].getCurrentVersion()));
           }
         });
 
     return deleteResult.get() > 0;
   }
 
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "deleteTableMetasByLegacyTimeline")
   public int deleteTableMetasByLegacyTimeline(Long legacyTimeline, int limit) {
     return SessionUtils.doWithCommitAndFetchResult(
-        TableMetaMapper.class,
-        mapper -> mapper.deleteTableMetasByLegacyTimeline(legacyTimeline, limit));
+            TableMetaMapper.class,
+            mapper -> mapper.deleteTableMetasByLegacyTimeline(legacyTimeline, limit))
+        + deleteTableVersionByLegacyTimeline(legacyTimeline, limit);
+  }
+
+  @Monitored(
+      metricsSource = GRAVITINO_RELATIONAL_STORE_METRIC_NAME,
+      baseMetricName = "deleteTableVersionByLegacyTimeline")
+  public int deleteTableVersionByLegacyTimeline(Long legacyTimeline, int limit) {
+    return SessionUtils.doWithCommitAndFetchResult(
+        TableVersionMapper.class,
+        mapper -> mapper.deleteTableVersionByLegacyTimeline(legacyTimeline, limit));
   }
 
   private void fillTablePOBuilderParentEntityId(TablePO.Builder builder, Namespace namespace) {
     NamespaceUtil.checkTable(namespace);
-    Long[] parentEntityIds =
-        CommonMetaService.getInstance().getParentEntityIdsByNamespace(namespace);
-    builder.withMetalakeId(parentEntityIds[0]);
-    builder.withCatalogId(parentEntityIds[1]);
-    builder.withSchemaId(parentEntityIds[2]);
+    NamespacedEntityId namespacedEntityId =
+        EntityIdService.getEntityIds(
+            NameIdentifier.of(namespace.levels()), Entity.EntityType.SCHEMA);
+    builder.withMetalakeId(namespacedEntityId.namespaceIds()[0]);
+    builder.withCatalogId(namespacedEntityId.namespaceIds()[1]);
+    builder.withSchemaId(namespacedEntityId.entityId());
   }
 
   private TablePO getTablePOBySchemaIdAndName(Long schemaId, String tableName) {
@@ -274,7 +334,6 @@ public class TableMetaService {
         SessionUtils.getWithoutCommit(
             TableMetaMapper.class,
             mapper -> mapper.selectTableMetaBySchemaIdAndName(schemaId, tableName));
-
     if (tablePO == null) {
       throw new NoSuchEntityException(
           NoSuchEntityException.NO_SUCH_ENTITY_MESSAGE,
