@@ -66,6 +66,7 @@ import org.apache.gravitino.exceptions.NoSuchFilesetException;
 import org.apache.gravitino.exceptions.NoSuchLocationNameException;
 import org.apache.gravitino.exceptions.NoSuchModelException;
 import org.apache.gravitino.exceptions.NoSuchModelVersionException;
+import org.apache.gravitino.exceptions.NoSuchModelVersionURINameException;
 import org.apache.gravitino.exceptions.NoSuchSchemaException;
 import org.apache.gravitino.exceptions.NoSuchTableException;
 import org.apache.gravitino.exceptions.NoSuchTopicException;
@@ -796,6 +797,18 @@ public class TestCatalogOperations
         .toArray();
   }
 
+  @Override
+  public ModelVersion[] listModelVersionInfos(NameIdentifier ident) throws NoSuchModelException {
+    if (!models.containsKey(ident)) {
+      throw new NoSuchModelException("Model %s does not exist", ident);
+    }
+
+    return modelVersions.entrySet().stream()
+        .filter(e -> e.getKey().getLeft().equals(ident))
+        .map(e -> e.getValue())
+        .toArray(ModelVersion[]::new);
+  }
+
   @Override
   public ModelVersion getModelVersion(NameIdentifier ident, int version)
       throws NoSuchModelVersionException {
@@ -835,7 +848,7 @@ public class TestCatalogOperations
   @Override
   public void linkModelVersion(
       NameIdentifier ident,
-      String uri,
+      Map<String, String> uris,
       String[] aliases,
       String comment,
       Map<String, String> properties)
@@ -844,6 +857,19 @@ public class TestCatalogOperations
       throw new NoSuchModelException("Model %s does not exist", ident);
     }
 
+    if (uris == null || uris.isEmpty()) {
+      throw new IllegalArgumentException("Uri must be set for model version");
+    }
+    uris.forEach(
+        (name, uri) -> {
+          if (StringUtils.isBlank(name)) {
+            throw new IllegalArgumentException("URI name must not be blank");
+          }
+          if (StringUtils.isBlank(uri)) {
+            throw new IllegalArgumentException("URI must not be blank for name: " + name);
+          }
+        });
+
     String[] aliasArray = aliases != null ? aliases : new String[0];
     for (String alias : aliasArray) {
       Pair<NameIdentifier, String> aliasPair = Pair.of(ident, alias);
@@ -859,7 +885,7 @@ public class TestCatalogOperations
             .withVersion(version)
             .withAliases(aliases)
             .withComment(comment)
-            .withUri(uri)
+            .withUris(uris)
             .withProperties(properties)
             .withAuditInfo(
                 AuditInfo.builder().withCreator("test").withCreateTime(Instant.now()).build())
@@ -883,6 +909,22 @@ public class TestCatalogOperations
     models.put(ident, updatedModel);
   }
 
+  @Override
+  public String getModelVersionUri(NameIdentifier ident, String alias, String uriName)
+      throws NoSuchModelVersionException, NoSuchModelVersionURINameException {
+    Model model = getModel(ident);
+    ModelVersion modelVersion = getModelVersion(ident, alias);
+    return internalGetModelVersionUri(model, modelVersion, uriName);
+  }
+
+  @Override
+  public String getModelVersionUri(NameIdentifier ident, int version, String uriName)
+      throws NoSuchModelVersionException, NoSuchModelVersionURINameException {
+    Model model = getModel(ident);
+    ModelVersion modelVersion = getModelVersion(ident, version);
+    return internalGetModelVersionUri(model, modelVersion, uriName);
+  }
+
   @Override
   public boolean deleteModelVersion(NameIdentifier ident, int version) {
     if (!models.containsKey(ident)) {
@@ -1032,6 +1074,44 @@ public class TestCatalogOperations
     return internalUpdateModelVersion(ident, version, changes);
   }
 
+  private String internalGetModelVersionUri(
+      Model model, ModelVersion modelVersion, String uriName) {
+    Map<String, String> uris = modelVersion.uris();
+    // If the uriName is not null, get from the uris directly
+    if (uriName != null) {
+      return getUriByName(uris, uriName);
+    }
+
+    // If there is only one uri of the model version, use it
+    if (uris.size() == 1) {
+      return uris.values().iterator().next();
+    }
+
+    // If the uri name is null, try to get the default uri name from the model version properties
+    Map<String, String> modelVersionProperties = modelVersion.properties();
+    if (modelVersionProperties.containsKey(ModelVersion.PROPERTY_DEFAULT_URI_NAME)) {
+      String defaultUriName = modelVersionProperties.get(ModelVersion.PROPERTY_DEFAULT_URI_NAME);
+      return getUriByName(uris, defaultUriName);
+    }
+
+    // If the default uri name is not set for the model version, try to get the default uri name
+    // from the model properties
+    Map<String, String> modelProperties = model.properties();
+    if (modelProperties.containsKey(ModelVersion.PROPERTY_DEFAULT_URI_NAME)) {
+      String defaultUriName = modelProperties.get(ModelVersion.PROPERTY_DEFAULT_URI_NAME);
+      return getUriByName(uris, defaultUriName);
+    }
+
+    throw new IllegalArgumentException("Either uri name of default uri name should be provided");
+  }
+
+  private String getUriByName(Map<String, String> uris, String uriName) {
+    if (!uris.containsKey(uriName)) {
+      throw new NoSuchModelVersionURINameException("URI name %s does not exist", uriName);
+    }
+    return uris.get(uriName);
+  }
+
   private ModelVersion internalUpdateModelVersion(
       NameIdentifier ident, int version, ModelVersionChange... changes)
       throws NoSuchModelException, NoSuchModelVersionException, IllegalArgumentException {
@@ -1053,7 +1133,7 @@ public class TestCatalogOperations
     String newComment = testModelVersion.comment();
     int newVersion = testModelVersion.version();
     String[] newAliases = testModelVersion.aliases();
-    String newUri = testModelVersion.uri();
+    Map<String, String> newUris = Maps.newHashMap(testModelVersion.uris());
 
     for (ModelVersionChange change : changes) {
       if (change instanceof ModelVersionChange.UpdateComment) {
@@ -1082,20 +1162,32 @@ public class TestCatalogOperations
 
       } else if (change instanceof ModelVersionChange.UpdateUri) {
         ModelVersionChange.UpdateUri updateUriChange = (ModelVersionChange.UpdateUri) change;
-        newUri = updateUriChange.newUri();
+        newUris.replace(updateUriChange.uriName(), updateUriChange.newUri());
+
+      } else if (change instanceof ModelVersionChange.AddUri) {
+        ModelVersionChange.AddUri addUriChange = (ModelVersionChange.AddUri) change;
+        newUris.putIfAbsent(addUriChange.uriName(), addUriChange.uri());
+
+      } else if (change instanceof ModelVersionChange.RemoveUri) {
+        ModelVersionChange.RemoveUri removeUriChange = (ModelVersionChange.RemoveUri) change;
+        newUris.remove(removeUriChange.uriName());
 
       } else {
         throw new IllegalArgumentException("Unsupported model version change: " + change);
       }
     }
 
+    if (newUris.isEmpty()) {
+      throw new IllegalArgumentException("Model version URI cannot be empty");
+    }
+
     TestModelVersion updatedModelVersion =
         TestModelVersion.builder()
             .withVersion(newVersion)
             .withComment(newComment)
             .withProperties(newProps)
             .withAuditInfo(updatedAuditInfo)
-            .withUri(newUri)
+            .withUris(newUris)
             .withAliases(newAliases)
             .build();
 
