@@ -31,6 +31,14 @@ import org.apache.gravitino.Namespace;
 import org.apache.gravitino.authorization.Privileges;
 import org.apache.gravitino.authorization.SecurableObjects;
 import org.apache.gravitino.file.Fileset;
+import org.apache.gravitino.rel.expressions.NamedReference;
+import org.apache.gravitino.rel.expressions.distributions.Distribution;
+import org.apache.gravitino.rel.expressions.distributions.Distributions;
+import org.apache.gravitino.rel.expressions.sorts.SortDirection;
+import org.apache.gravitino.rel.expressions.sorts.SortOrder;
+import org.apache.gravitino.rel.expressions.sorts.SortOrders;
+import org.apache.gravitino.rel.indexes.Index;
+import org.apache.gravitino.rel.indexes.Indexes;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 
@@ -152,13 +160,35 @@ public class TestEntity {
 
   @Test
   public void testTable() {
+    String comment = "test table comment";
+    Map<String, String> tableProperties = ImmutableMap.of("tableKey1", "tableValue1");
+    SortOrder[] sortOrders =
+        new SortOrder[] {SortOrders.of(NamedReference.field("col1"), SortDirection.ASCENDING)};
+    Index[] indexes =
+        new Index[] {Indexes.of(Index.IndexType.BTREE, "idx1", new String[][] {{"col1"}})};
+    Distribution distribution = Distributions.hash(4, NamedReference.field("col1"));
+
     TableEntity testTable =
-        TableEntity.builder().withId(tableId).withName(tableName).withAuditInfo(auditInfo).build();
+        TableEntity.builder()
+            .withId(tableId)
+            .withName(tableName)
+            .withAuditInfo(auditInfo)
+            .withSortOrders(sortOrders)
+            .withProperties(tableProperties)
+            .withComment(comment)
+            .withIndexes(indexes)
+            .withDistribution(distribution)
+            .build();
 
     Map<Field, Object> fields = testTable.fields();
     Assertions.assertEquals(tableId, fields.get(TableEntity.ID));
     Assertions.assertEquals(tableName, fields.get(TableEntity.NAME));
     Assertions.assertEquals(auditInfo, fields.get(TableEntity.AUDIT_INFO));
+    Assertions.assertEquals(tableProperties, fields.get(TableEntity.PROPERTIES));
+    Assertions.assertEquals(comment, fields.get(TableEntity.COMMENT));
+    Assertions.assertEquals(sortOrders, fields.get(TableEntity.SORT_ORDERS));
+    Assertions.assertEquals(indexes, fields.get(TableEntity.INDEXES));
+    Assertions.assertEquals(distribution, fields.get(TableEntity.DISTRIBUTION));
   }
 
   @Test
