@@ -18,24 +18,29 @@
  */
 package org.apache.gravitino.storage.relational.service;
 
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import com.google.common.collect.ImmutableMap;
 import java.io.IOException;
 import java.time.Instant;
 import java.util.List;
 import java.util.Map;
 import java.util.function.Function;
+import org.apache.gravitino.Entity;
 import org.apache.gravitino.EntityAlreadyExistsException;
 import org.apache.gravitino.NameIdentifier;
 import org.apache.gravitino.Namespace;
 import org.apache.gravitino.exceptions.NoSuchEntityException;
-import org.apache.gravitino.meta.AuditInfo;
+import org.apache.gravitino.meta.BaseMetalake;
 import org.apache.gravitino.meta.ModelEntity;
 import org.apache.gravitino.storage.RandomIdGenerator;
 import org.apache.gravitino.storage.relational.TestJDBCBackend;
 import org.apache.gravitino.storage.relational.po.ModelPO;
 import org.apache.gravitino.storage.relational.utils.POConverters;
+import org.apache.gravitino.utils.NamespaceUtil;
 import org.junit.jupiter.api.Assertions;
-import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestTemplate;
 
 public class TestModelMetaService extends TestJDBCBackend {
 
@@ -47,12 +52,43 @@ public class TestModelMetaService extends TestJDBCBackend {
 
   private static final Namespace MODEL_NS = Namespace.of(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME);
 
-  private final AuditInfo auditInfo =
-      AuditInfo.builder().withCreator("test").withCreateTime(Instant.now()).build();
+  @TestTemplate
+  public void testMetaLifeCycleFromCreationToDeletion() throws IOException {
+    BaseMetalake metalake = createAndInsertMakeLake(METALAKE_NAME);
+    createAndInsertCatalog(METALAKE_NAME, CATALOG_NAME);
+    createAndInsertSchema(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME);
 
-  @Test
+    ModelEntity model =
+        createModelEntity(
+            RandomIdGenerator.INSTANCE.nextId(),
+            NamespaceUtil.ofModel(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME),
+            "model",
+            "model comment",
+            1,
+            ImmutableMap.of("key", "value"),
+            AUDIT_INFO);
+    backend.insert(model, false);
+
+    List<ModelEntity> models = backend.list(model.namespace(), Entity.EntityType.MODEL, true);
+    assertTrue(models.contains(model));
+
+    // meta data soft delete
+    backend.delete(metalake.nameIdentifier(), Entity.EntityType.METALAKE, true);
+    assertFalse(backend.exists(model.nameIdentifier(), Entity.EntityType.MODEL));
+
+    // check legacy record after soft delete
+    assertTrue(legacyRecordExistsInDB(model.id(), Entity.EntityType.MODEL));
+
+    // meta data hard delete
+    for (Entity.EntityType entityType : Entity.EntityType.values()) {
+      backend.hardDeleteLegacyData(entityType, Instant.now().toEpochMilli() + 1000);
+    }
+    assertFalse(legacyRecordExistsInDB(model.id(), Entity.EntityType.MODEL));
+  }
+
+  @TestTemplate
   public void testInsertAndSelectModel() throws IOException {
-    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, auditInfo);
+    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, AUDIT_INFO);
     Map<String, String> properties = ImmutableMap.of("k1", "v1");
 
     ModelEntity modelEntity =
@@ -63,7 +99,7 @@ public class TestModelMetaService extends TestJDBCBackend {
             "model1 comment",
             0,
             properties,
-            auditInfo);
+            AUDIT_INFO);
 
     Assertions.assertDoesNotThrow(
         () -> ModelMetaService.getInstance().insertModel(modelEntity, false));
@@ -86,7 +122,7 @@ public class TestModelMetaService extends TestJDBCBackend {
             null,
             modelEntity.latestVersion(),
             null,
-            auditInfo);
+            AUDIT_INFO);
     Assertions.assertDoesNotThrow(
         () -> ModelMetaService.getInstance().insertModel(modelEntity2, true));
     ModelEntity registeredModelEntity2 =
@@ -110,7 +146,8 @@ public class TestModelMetaService extends TestJDBCBackend {
         NoSuchEntityException.class, () -> ModelMetaService.getInstance().getModelPOById(111L));
 
     // Test get model id by name
-    Long schemaId = CommonMetaService.getInstance().getParentEntityIdByNamespace(MODEL_NS);
+    Long schemaId =
+        EntityIdService.getEntityId(NameIdentifier.of(MODEL_NS.levels()), Entity.EntityType.SCHEMA);
     Long modelId =
         ModelMetaService.getInstance().getModelIdBySchemaIdAndModelName(schemaId, "model2");
     Assertions.assertEquals(modelEntity2.id(), modelId);
@@ -121,9 +158,9 @@ public class TestModelMetaService extends TestJDBCBackend {
         () -> ModelMetaService.getInstance().getModelIdBySchemaIdAndModelName(schemaId, "model3"));
   }
 
-  @Test
+  @TestTemplate
   public void testInsertAndListModels() throws IOException {
-    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, auditInfo);
+    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, AUDIT_INFO);
     Map<String, String> properties = ImmutableMap.of("k1", "v1");
 
     ModelEntity modelEntity1 =
@@ -134,7 +171,7 @@ public class TestModelMetaService extends TestJDBCBackend {
             "model1 comment",
             0,
             properties,
-            auditInfo);
+            AUDIT_INFO);
     ModelEntity modelEntity2 =
         createModelEntity(
             RandomIdGenerator.INSTANCE.nextId(),
@@ -143,7 +180,7 @@ public class TestModelMetaService extends TestJDBCBackend {
             "model2 comment",
             0,
             properties,
-            auditInfo);
+            AUDIT_INFO);
 
     Assertions.assertDoesNotThrow(
         () -> ModelMetaService.getInstance().insertModel(modelEntity1, false));
@@ -164,9 +201,9 @@ public class TestModelMetaService extends TestJDBCBackend {
                 .listModelsByNamespace(Namespace.of(METALAKE_NAME, CATALOG_NAME, "inexistent")));
   }
 
-  @Test
+  @TestTemplate
   public void testInsertAndDeleteModel() throws IOException {
-    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, auditInfo);
+    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, AUDIT_INFO);
     Map<String, String> properties = ImmutableMap.of("k1", "v1");
 
     ModelEntity modelEntity =
@@ -177,7 +214,7 @@ public class TestModelMetaService extends TestJDBCBackend {
             "model1 comment",
             0,
             properties,
-            auditInfo);
+            AUDIT_INFO);
 
     Assertions.assertDoesNotThrow(
         () -> ModelMetaService.getInstance().insertModel(modelEntity, false));
@@ -201,9 +238,9 @@ public class TestModelMetaService extends TestJDBCBackend {
             .deleteModel(NameIdentifier.of(METALAKE_NAME, CATALOG_NAME, "inexistent", "model1")));
   }
 
-  @Test
+  @TestTemplate
   void testInsertAndRenameModel() throws IOException {
-    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, auditInfo);
+    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, AUDIT_INFO);
     Map<String, String> properties = ImmutableMap.of("k1", "v1");
     String newName = "new_model_name";
 
@@ -215,7 +252,7 @@ public class TestModelMetaService extends TestJDBCBackend {
             "model1 comment",
             0,
             properties,
-            auditInfo);
+            AUDIT_INFO);
 
     Assertions.assertDoesNotThrow(
         () -> ModelMetaService.getInstance().insertModel(modelEntity, false));
@@ -244,9 +281,9 @@ public class TestModelMetaService extends TestJDBCBackend {
                 .updateModel(NameIdentifier.of(MODEL_NS, "model3"), renameUpdater));
   }
 
-  @Test
+  @TestTemplate
   void testInsertAndUpdateModelComment() throws IOException {
-    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, auditInfo);
+    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, AUDIT_INFO);
     Map<String, String> properties = ImmutableMap.of("k1", "v1");
     String newComment = "new_model_comment";
 
@@ -258,7 +295,7 @@ public class TestModelMetaService extends TestJDBCBackend {
             "model1 comment",
             0,
             properties,
-            auditInfo);
+            AUDIT_INFO);
 
     Assertions.assertDoesNotThrow(
         () -> ModelMetaService.getInstance().insertModel(modelEntity, false));
@@ -285,11 +322,42 @@ public class TestModelMetaService extends TestJDBCBackend {
         () ->
             ModelMetaService.getInstance()
                 .updateModel(NameIdentifier.of(MODEL_NS, "model3"), renameUpdater));
+
+    // test update model comment from null
+    ModelEntity modelEntity4 =
+        createModelEntity(
+            RandomIdGenerator.INSTANCE.nextId(),
+            MODEL_NS,
+            "model4",
+            "model4 comment",
+            0,
+            properties,
+            AUDIT_INFO);
+    ModelMetaService.getInstance().insertModel(modelEntity4, false);
+
+    ModelMetaService.getInstance()
+        .updateModel(
+            modelEntity4.nameIdentifier(),
+            entity -> {
+              ModelEntity model = (ModelEntity) entity;
+              return ModelEntity.builder()
+                  .withId(model.id())
+                  .withName(model.name())
+                  .withNamespace(model.namespace())
+                  .withComment("model comment updated")
+                  .withLatestVersion(model.latestVersion())
+                  .withProperties(model.properties())
+                  .withAuditInfo(model.auditInfo())
+                  .build();
+            });
+    ModelEntity updatedModel4 =
+        ModelMetaService.getInstance().getModelByIdentifier(modelEntity4.nameIdentifier());
+    Assertions.assertEquals("model comment updated", updatedModel4.comment());
   }
 
-  @Test
+  @TestTemplate
   void testInsertAndUpdateModelProperties() throws IOException {
-    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, auditInfo);
+    createParentEntities(METALAKE_NAME, CATALOG_NAME, SCHEMA_NAME, AUDIT_INFO);
     Map<String, String> properties = ImmutableMap.of("k1", "v1", "k2", "v2");
     Map<String, String> newProps = ImmutableMap.of("k1", "v1", "k3", "v3");
 
@@ -301,7 +369,7 @@ public class TestModelMetaService extends TestJDBCBackend {
             "model1 comment",
             0,
             properties,
-            auditInfo);
+            AUDIT_INFO);
 
     Assertions.assertDoesNotThrow(
         () -> ModelMetaService.getInstance().insertModel(modelEntity, false));
