@@ -32,6 +32,10 @@ val scalaCollectionCompatVersion: String = libs.versions.scala.collection.compat
 
 dependencies {
   implementation(project(":api"))
+  implementation(project(":bundles:aliyun"))
+  implementation(project(":bundles:aws"))
+  implementation(project(":bundles:azure"))
+  implementation(project(":bundles:gcp"))
   implementation(project(":catalogs:catalog-common"))
   implementation(project(":clients:client-java"))
   implementation(project(":core")) {
@@ -52,23 +56,34 @@ dependencies {
   implementation(libs.bundles.metrics)
   implementation(libs.bundles.prometheus)
   implementation(libs.caffeine)
+  implementation(libs.cglib) {
+    // The version of build-in asm is 7.1, which is not compatible with Java 17 well
+    exclude("org.ow2.asm")
+  }
+  implementation(libs.commons.dbcp2)
   implementation(libs.commons.lang3)
+  implementation(libs.concurrent.trees)
   implementation(libs.guava)
   implementation(libs.jackson.annotations)
   implementation(libs.jackson.databind)
   implementation(libs.jackson.datatype.jdk8)
   implementation(libs.jackson.datatype.jsr310)
+  implementation(libs.jcasbin) {
+    exclude(group = "com.fasterxml.jackson.core", module = "jackson-databind")
+  }
   implementation(libs.metrics.jersey2)
+  implementation(libs.mybatis)
+  implementation(libs.ognl)
 
   annotationProcessor(libs.lombok)
   compileOnly(libs.lombok)
 
-  // Iceberg doesn't provide Aliyun bundle jar, use Gravitino Aliyun bundle to provide OSS packages
-  testImplementation(project(":bundles:aliyun-bundle"))
-  testImplementation(project(":bundles:aws", configuration = "shadow"))
-  testImplementation(project(":bundles:gcp", configuration = "shadow"))
-  testImplementation(project(":bundles:azure", configuration = "shadow"))
+  testImplementation(project(":bundles:iceberg-aliyun-bundle"))
+  testImplementation(project(":bundles:iceberg-aws-bundle"))
+  testImplementation(project(":bundles:iceberg-gcp-bundle"))
+  testImplementation(project(":bundles:iceberg-azure-bundle"))
   testImplementation(project(":integration-test-common", "testArtifacts"))
+  testImplementation(project(":server"))
 
   testImplementation("org.scala-lang.modules:scala-collection-compat_$scalaVersion:$scalaCollectionCompatVersion")
   testImplementation("org.apache.iceberg:iceberg-spark-runtime-${sparkMajorVersion}_$scalaVersion:$icebergVersion")
@@ -80,11 +95,9 @@ dependencies {
     exclude("org.rocksdb")
   }
 
-  testImplementation(libs.iceberg.aws.bundle)
-  testImplementation(libs.iceberg.gcp.bundle)
-  testImplementation(libs.iceberg.azure.bundle) {
-    exclude("com.google.guava", "guava")
-  }
+  testImplementation(libs.h2db)
+  testImplementation(libs.mysql.driver)
+  testImplementation(libs.postgresql.driver)
   testImplementation(libs.jersey.test.framework.core) {
     exclude(group = "org.junit.jupiter")
   }
@@ -94,9 +107,22 @@ dependencies {
   testImplementation(libs.junit.jupiter.api)
   testImplementation(libs.junit.jupiter.params)
   testImplementation(libs.mockito.core)
+  testImplementation(libs.mysql.driver)
+  testImplementation(libs.postgresql.driver)
   testImplementation(libs.sqlite.jdbc)
   testImplementation(libs.slf4j.api)
   testImplementation(libs.testcontainers)
+  testImplementation(libs.cglib) {
+    // The version of build-in asm is 7.1, which is not compatible with Java 17 well
+    exclude("org.ow2.asm")
+  }
+  testImplementation(libs.asm)
+  testImplementation(libs.testcontainers.postgresql)
+
+  // Add Hadoop 3.3+ dependencies since Spark's Hadoop is excluded
+  // Required for Iceberg 1.10+ which uses newer Hadoop APIs like FileSystem.openFile()
+  testImplementation(libs.hadoop3.client.api)
+  testImplementation(libs.hadoop3.client.runtime)
 
   testRuntimeOnly(libs.junit.jupiter.engine)
 }
