@@ -14,6 +14,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+import logging
 
 from tests.unit.tools.mock_operation import (
     MockCatalogOperation,
@@ -21,3 +22,5 @@ from tests.unit.tools.mock_operation import (
     MockSchemaOperation,
     MockTableOperation,
 )
+
+logging.disable(logging.INFO)
