@@ -34,6 +34,8 @@ import org.apache.gravitino.authorization.GravitinoAuthorizer;
 import org.apache.gravitino.server.authorization.GravitinoAuthorizerProvider;
 import org.apache.gravitino.utils.NameIdentifierUtil;
 import org.apache.gravitino.utils.PrincipalUtils;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /** Evaluate the runtime result of the AuthorizationExpression. */
 public class AuthorizationExpressionEvaluator {
@@ -41,6 +43,9 @@ public class AuthorizationExpressionEvaluator {
   private final String ognlAuthorizationExpression;
   private final GravitinoAuthorizer authorizer;
 
+  private static final Logger LOGGER =
+      LoggerFactory.getLogger(AuthorizationExpressionEvaluator.class);
+
   /**
    * Use {@link AuthorizationExpressionConverter} to convert the authorization expression into an
    * OGNL expression, and then call {@link GravitinoAuthorizer} to perform permission verification.
@@ -49,6 +54,7 @@ public class AuthorizationExpressionEvaluator {
    */
   public AuthorizationExpressionEvaluator(String expression) {
     this(expression, GravitinoAuthorizerProvider.getInstance().getGravitinoAuthorizer());
+    LOGGER.debug("Authorization expression: {}", expression);
   }
 
   /**
@@ -74,7 +80,8 @@ public class AuthorizationExpressionEvaluator {
       Map<Entity.EntityType, NameIdentifier> metadataNames,
       AuthorizationRequestContext requestContext) {
     Principal currentPrincipal = PrincipalUtils.getCurrentPrincipal();
-    return evaluate(metadataNames, new HashMap<>(), requestContext, currentPrincipal);
+    return evaluate(
+        metadataNames, new HashMap<>(), requestContext, currentPrincipal, Optional.empty());
   }
 
   /**
@@ -84,13 +91,15 @@ public class AuthorizationExpressionEvaluator {
    * @param metadataNames key-metadata type, value-metadata NameIdentifier
    * @param requestContext authorization request context
    * @param principal current principal
+   * @param entityType entityType
    * @return authorization result
    */
   public boolean evaluate(
       Map<Entity.EntityType, NameIdentifier> metadataNames,
       AuthorizationRequestContext requestContext,
-      Principal principal) {
-    return evaluate(metadataNames, new HashMap<>(), requestContext, principal);
+      Principal principal,
+      Optional<String> entityType) {
+    return evaluate(metadataNames, new HashMap<>(), requestContext, principal, entityType);
   }
 
   /**
@@ -99,14 +108,16 @@ public class AuthorizationExpressionEvaluator {
    *
    * @param metadataNames key-metadata type, value-metadata NameIdentifier
    * @param pathParams params from request path
+   * @param entityType entityType
    * @return authorization result
    */
   public boolean evaluate(
       Map<Entity.EntityType, NameIdentifier> metadataNames,
       Map<String, Object> pathParams,
-      AuthorizationRequestContext requestContext) {
+      AuthorizationRequestContext requestContext,
+      Optional<String> entityType) {
     Principal currentPrincipal = PrincipalUtils.getCurrentPrincipal();
-    return evaluate(metadataNames, pathParams, requestContext, currentPrincipal);
+    return evaluate(metadataNames, pathParams, requestContext, currentPrincipal, entityType);
   }
 
   /**
@@ -123,11 +134,13 @@ public class AuthorizationExpressionEvaluator {
       Map<Entity.EntityType, NameIdentifier> metadataNames,
       Map<String, Object> pathParams,
       AuthorizationRequestContext requestContext,
-      Principal currentPrincipal) {
+      Principal currentPrincipal,
+      Optional<String> entityType) {
     OgnlContext ognlContext = Ognl.createDefaultContext(null);
     ognlContext.put("principal", currentPrincipal);
     ognlContext.put("authorizer", authorizer);
     ognlContext.put("authorizationContext", requestContext);
+    ognlContext.put("entityType", entityType.orElse(null));
     ognlContext.putAll(pathParams);
     metadataNames.forEach(
         (type, entityNameIdent) -> {
