@@ -18,6 +18,7 @@
  */
 package org.apache.gravitino.server.web.rest;
 
+import static org.apache.gravitino.server.authorization.expression.AuthorizationExpressionConstants.CAN_ACCESS_METADATA;
 import static org.apache.gravitino.server.authorization.expression.AuthorizationExpressionConverter.CAN_SET_OWNER;
 
 import com.codahale.metrics.annotation.ResponseMetered;
@@ -45,7 +46,9 @@ import org.apache.gravitino.dto.util.DTOConverters;
 import org.apache.gravitino.metrics.MetricNames;
 import org.apache.gravitino.server.authorization.NameBindings;
 import org.apache.gravitino.server.authorization.annotations.AuthorizationExpression;
+import org.apache.gravitino.server.authorization.annotations.AuthorizationFullName;
 import org.apache.gravitino.server.authorization.annotations.AuthorizationMetadata;
+import org.apache.gravitino.server.authorization.annotations.AuthorizationObjectType;
 import org.apache.gravitino.server.web.Utils;
 import org.apache.gravitino.utils.MetadataObjectUtil;
 
@@ -69,10 +72,14 @@ public class OwnerOperations {
   @Produces("application/vnd.gravitino.v1+json")
   @Timed(name = "get-object-owner." + MetricNames.HTTP_PROCESS_DURATION, absolute = true)
   @ResponseMetered(name = "get-object-owner", absolute = true)
+  @AuthorizationExpression(
+      expression = CAN_ACCESS_METADATA,
+      errorMessage = "Current user can not get this objects's owner")
   public Response getOwnerForObject(
-      @PathParam("metalake") String metalake,
-      @PathParam("metadataObjectType") String metadataObjectType,
-      @PathParam("fullName") String fullName) {
+      @PathParam("metalake") @AuthorizationMetadata(type = Entity.EntityType.METALAKE)
+          String metalake,
+      @PathParam("metadataObjectType") @AuthorizationObjectType String metadataObjectType,
+      @PathParam("fullName") @AuthorizationFullName String fullName) {
     try {
       MetadataObject object =
           MetadataObjects.parse(
