@@ -51,32 +51,33 @@ public class TestModelAuthorizationExpression {
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER")));
     assertTrue(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER", "CATALOG::USE_CATALOG")));
     assertTrue(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER", "METALAKE::USE_CATALOG")));
-    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL")));
+    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL")));
     assertFalse(
-        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA")));
-    assertTrue(
-        mockEvaluator.getResult(
-            ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
+        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA")));
     assertTrue(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "CATALOG::CREATE_MODEL", "CATALOG::USE_SCHEMA", "CATALOG::USE_CATALOG")));
+                "SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
     assertTrue(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "METALAKE::CREATE_MODEL", "METALAKE::USE_SCHEMA", "METALAKE::USE_CATALOG")));
+                "CATALOG::REGISTER_MODEL", "CATALOG::USE_SCHEMA", "CATALOG::USE_CATALOG")));
+    assertTrue(
+        mockEvaluator.getResult(
+            ImmutableSet.of(
+                "METALAKE::REGISTER_MODEL", "METALAKE::USE_SCHEMA", "METALAKE::USE_CATALOG")));
     assertFalse(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "METALAKE::CREATE_MODEL",
-                "CATALOG::DENY_CREATE_MODEL",
+                "METALAKE::REGISTER_MODEL",
+                "CATALOG::DENY_REGISTER_MODEL",
                 "METALAKE::USE_SCHEMA",
                 "METALAKE::USE_CATALOG")));
     assertFalse(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "METALAKE::DENY_CREATE_MODEL",
-                "CATALOG::CREATE_MODEL",
+                "METALAKE::DENY_REGISTER_MODEL",
+                "CATALOG::REGISTER_MODEL",
                 "METALAKE::USE_SCHEMA",
                 "METALAKE::USE_CATALOG")));
   }
@@ -95,12 +96,13 @@ public class TestModelAuthorizationExpression {
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER")));
     assertTrue(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER", "CATALOG::USE_CATALOG")));
     assertTrue(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER", "METALAKE::USE_CATALOG")));
-    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL")));
+    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL")));
     assertFalse(
-        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA")));
+        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA")));
     assertFalse(
         mockEvaluator.getResult(
-            ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
+            ImmutableSet.of(
+                "SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::USE_MODEL")));
     assertFalse(
         mockEvaluator.getResult(ImmutableSet.of("SCHEMA::USE_MODEL", "SCHEMA::USE_SCHEMA")));
@@ -158,12 +160,13 @@ public class TestModelAuthorizationExpression {
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER")));
     assertTrue(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER", "CATALOG::USE_CATALOG")));
     assertTrue(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER", "METALAKE::USE_CATALOG")));
-    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL")));
+    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL")));
     assertFalse(
-        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA")));
+        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA")));
     assertFalse(
         mockEvaluator.getResult(
-            ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
+            ImmutableSet.of(
+                "SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER", "SCHEMA::USE_SCHEMA")));
     assertTrue(
@@ -203,12 +206,13 @@ public class TestModelAuthorizationExpression {
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER")));
     assertTrue(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER", "CATALOG::USE_CATALOG")));
     assertTrue(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER", "METALAKE::USE_CATALOG")));
-    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL")));
+    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL")));
     assertFalse(
-        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA")));
+        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA")));
     assertFalse(
         mockEvaluator.getResult(
-            ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
+            ImmutableSet.of(
+                "SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER", "SCHEMA::USE_SCHEMA")));
     assertTrue(
@@ -253,18 +257,18 @@ public class TestModelAuthorizationExpression {
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER")));
     assertTrue(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER", "CATALOG::USE_CATALOG")));
     assertTrue(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::OWNER", "METALAKE::USE_CATALOG")));
-    assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::CREATE_MODEL_VERSION")));
+    assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::LINK_MODEL_VERSION")));
     assertFalse(
         mockEvaluator.getResult(
-            ImmutableSet.of("MODEL::CREATE_MODEL_VERSION", "SCHEMA::USE_SCHEMA")));
+            ImmutableSet.of("MODEL::LINK_MODEL_VERSION", "SCHEMA::USE_SCHEMA")));
     assertFalse(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "MODEL::CREATE_MODEL_VERSION", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
+                "MODEL::LINK_MODEL_VERSION", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
     assertTrue(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "MODEL::CREATE_MODEL_VERSION",
+                "MODEL::LINK_MODEL_VERSION",
                 "MODEL::USE_MODEL",
                 "SCHEMA::USE_SCHEMA",
                 "CATALOG::USE_CATALOG")));
@@ -272,37 +276,37 @@ public class TestModelAuthorizationExpression {
     assertTrue(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "SCHEMA::CREATE_MODEL_VERSION",
+                "SCHEMA::LINK_MODEL_VERSION",
                 "MODEL::USE_MODEL",
                 "SCHEMA::USE_SCHEMA",
                 "CATALOG::USE_CATALOG")));
     assertTrue(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "CATALOG::CREATE_MODEL_VERSION",
+                "CATALOG::LINK_MODEL_VERSION",
                 "MODEL::USE_MODEL",
                 "CATALOG::USE_SCHEMA",
                 "CATALOG::USE_CATALOG")));
     assertTrue(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "METALAKE::CREATE_MODEL_VERSION",
+                "METALAKE::LINK_MODEL_VERSION",
                 "MODEL::USE_MODEL",
                 "METALAKE::USE_SCHEMA",
                 "METALAKE::USE_CATALOG")));
     assertFalse(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "METALAKE::CREATE_MODEL_VERSION",
-                "CATALOG::DENY_CREATE_MODEL_VERSION",
+                "METALAKE::LINK_MODEL_VERSION",
+                "CATALOG::DENY_LINK_MODEL_VERSION",
                 "MODEL::USE_MODEL",
                 "METALAKE::USE_SCHEMA",
                 "METALAKE::USE_CATALOG")));
     assertFalse(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "METALAKE::DENY_CREATE_MODEL_VERSION",
-                "CATALOG::CREATE_MODEL_VERSION",
+                "METALAKE::DENY_LINK_MODEL_VERSION",
+                "CATALOG::LINK_MODEL_VERSION",
                 "MODEL::USE_MODEL",
                 "METALAKE::USE_SCHEMA",
                 "METALAKE::USE_CATALOG")));
@@ -318,14 +322,14 @@ public class TestModelAuthorizationExpression {
     assertTrue(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "CATALOG::CREATE_MODEL_VERSION",
+                "CATALOG::LINK_MODEL_VERSION",
                 "MODEL::USE_MODEL",
                 "CATALOG::USE_SCHEMA",
                 "CATALOG::USE_CATALOG")));
     assertTrue(
         mockEvaluator.getResult(
             ImmutableSet.of(
-                "METALAKE::CREATE_MODEL_VERSION",
+                "METALAKE::LINK_MODEL_VERSION",
                 "MODEL::USE_MODEL",
                 "METALAKE::USE_SCHEMA",
                 "METALAKE::USE_CATALOG")));
@@ -357,12 +361,13 @@ public class TestModelAuthorizationExpression {
         mockEvaluator.getResult(
             ImmutableSet.of(
                 "SCHEMA::OWNER", "METALAKE::USE_CATALOG", "CATALOG::DENY_USE_CATALOG")));
-    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL")));
+    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL")));
     assertFalse(
-        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA")));
+        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA")));
     assertFalse(
         mockEvaluator.getResult(
-            ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
+            ImmutableSet.of(
+                "SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER", "SCHEMA::USE_SCHEMA")));
     assertTrue(
@@ -404,12 +409,13 @@ public class TestModelAuthorizationExpression {
         mockEvaluator.getResult(
             ImmutableSet.of(
                 "SCHEMA::OWNER", "METALAKE::USE_CATALOG", "CATALOG::DENY_USE_CATALOG")));
-    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL")));
+    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL")));
     assertFalse(
-        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA")));
+        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA")));
     assertFalse(
         mockEvaluator.getResult(
-            ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
+            ImmutableSet.of(
+                "SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER", "SCHEMA::USE_SCHEMA")));
     assertTrue(
@@ -450,12 +456,13 @@ public class TestModelAuthorizationExpression {
         mockEvaluator.getResult(
             ImmutableSet.of(
                 "SCHEMA::OWNER", "METALAKE::USE_CATALOG", "CATALOG::DENY_USE_CATALOG")));
-    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL")));
+    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL")));
     assertFalse(
-        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA")));
+        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA")));
     assertFalse(
         mockEvaluator.getResult(
-            ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
+            ImmutableSet.of(
+                "SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER", "SCHEMA::USE_SCHEMA")));
     assertTrue(
@@ -496,12 +503,13 @@ public class TestModelAuthorizationExpression {
         mockEvaluator.getResult(
             ImmutableSet.of(
                 "SCHEMA::OWNER", "METALAKE::USE_CATALOG", "CATALOG::DENY_USE_CATALOG")));
-    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL")));
+    assertFalse(mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL")));
     assertFalse(
-        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA")));
+        mockEvaluator.getResult(ImmutableSet.of("SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA")));
     assertFalse(
         mockEvaluator.getResult(
-            ImmutableSet.of("SCHEMA::CREATE_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
+            ImmutableSet.of(
+                "SCHEMA::REGISTER_MODEL", "SCHEMA::USE_SCHEMA", "CATALOG::USE_CATALOG")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER")));
     assertFalse(mockEvaluator.getResult(ImmutableSet.of("MODEL::OWNER", "SCHEMA::USE_SCHEMA")));
     assertTrue(
